@@ -6,24 +6,22 @@ the `astropy.coordinates` module.
 """
 from __future__ import absolute_import, division
 
+import warnings
+
 import numpy as np
 
 from astropy import units as u
 from astropy.coordinates.representation import (CartesianRepresentation,
                                                 UnitSphericalRepresentation,
                                                 SphericalRepresentation)
-from astropy.coordinates import (BaseCoordinateFrame,
+from astropy.coordinates.baseframe import (BaseCoordinateFrame,
                                            RepresentationMapping)
+from astropy.coordinates import Attribute, CoordinateAttribute, ConvertError
 
-try:
-    from astropy.coordinates import Attribute
-except ImportError:
-    from astropy.coordinates import FrameAttribute as Attribute
-
-from sunpy import sun  # For Carrington rotation number
+from sunpy import sun
 from .representation import (SphericalWrap180Representation, UnitSphericalWrap180Representation)
 
-from .frameattributes import TimeFrameAttributeSunPy
+from .frameattributes import TimeFrameAttributeSunPy, ObserverCoordinateAttribute
 
 RSUN_METERS = sun.constants.get('radius').si.to(u.m)
 DSUN_METERS = sun.constants.get('mean distance').si.to(u.m)
@@ -53,6 +51,9 @@ class HeliographicStonyhurst(BaseCoordinateFrame):
     radius: `astropy.units.Quantity` object.
         This quantity holds the radial distance. If not specified, it is, by
         default, the radius of the photosphere. Optional.
+    obstime: SunPy Time
+        The date and time of the observation, used to convert to heliographic
+        carrington coordinates.
 
     Examples
     --------
@@ -61,17 +62,17 @@ class HeliographicStonyhurst(BaseCoordinateFrame):
     >>> import astropy.units as u
     >>> sc = SkyCoord(1*u.deg, 1*u.deg, 2*u.km,
     ...               frame="heliographic_stonyhurst",
-    ...               dateobs="2010/01/01T00:00:45")
-    >>> sc
-    <SkyCoord (HelioGraphicStonyhurst): dateobs=2010-01-01 00:00:45,
-    lon=1.0 deg, lat=1.0 deg, rad=2.0 km>
-    >>> sc.frame
-    <HelioGraphicStonyhurst Coordinate: dateobs=2010-01-01 00:00:45,
-    lon=1.0 deg, lat=1.0 deg, rad=2.0 km>
-    >>> sc = SkyCoord(HelioGraphicStonyhurst(-10*u.deg, 2*u.deg))
-    >>> sc
-    <SkyCoord (HelioGraphicStonyhurst): dateobs=None, lon=-10.0 deg,
-    lat=2.0 deg, rad=695508.0 km>
+    ...               obstime="2010/01/01T00:00:45")
+    >>> sc # doctest: +FLOAT_CMP
+    <SkyCoord (HeliographicStonyhurst: obstime=2010-01-01 00:00:45): (lon, lat, radius) in (deg, deg, km)
+        ( 1.,  1.,  2.)>
+    >>> sc.frame # doctest: +FLOAT_CMP
+    <HeliographicStonyhurst Coordinate (obstime=2010-01-01 00:00:45): (lon, lat, radius) in (deg, deg, km)
+        ( 1.,  1.,  2.)>
+    >>> sc = SkyCoord(HeliographicStonyhurst(-10*u.deg, 2*u.deg))
+    >>> sc # doctest: +FLOAT_CMP
+    <SkyCoord (HeliographicStonyhurst: obstime=None): (lon, lat, radius) in (deg, deg, km)
+        (-10.,  2.,  695508.)>
 
     Notes
     -----
@@ -94,7 +95,7 @@ class HeliographicStonyhurst(BaseCoordinateFrame):
         ]
     }
 
-    dateobs = TimeFrameAttributeSunPy()
+    obstime = TimeFrameAttributeSunPy()
 
     def __init__(self, *args, **kwargs):
         _rep_kwarg = kwargs.get('representation', None)
@@ -112,7 +113,7 @@ class HeliographicStonyhurst(BaseCoordinateFrame):
             elif isinstance(self._data, UnitSphericalRepresentation):
                 distance = RSUN_METERS.to(u.km)
 
-            if distance:
+            if distance is not None:
                 self._data = self.default_representation(lat=self._data.lat,
                                                          lon=self._data.lon,
                                                          distance=distance)
@@ -140,6 +141,9 @@ class HeliographicCarrington(HeliographicStonyhurst):
     radius: `astropy.units.Quantity` object, optional, must be keyword.
         This quantity holds the radial distance. If not specified, it is, by
         default, the solar radius. Optional, must be keyword.
+    obstime: SunPy Time
+        The date and time of the observation, used to convert to heliographic
+        carrington coordinates.
 
     Examples
     --------
@@ -148,16 +152,16 @@ class HeliographicCarrington(HeliographicStonyhurst):
     >>> import astropy.units as u
     >>> sc = SkyCoord(1*u.deg, 2*u.deg, 3*u.km,
     ...               frame="heliographic_carrington",
-    ...               dateobs="2010/01/01T00:00:30")
-    >>> sc
-    <SkyCoord (HelioGraphicCarrington): dateobs=2010-01-01 00:00:30,
-    lon=1.0 deg, lat=2.0 deg, rad=3.0 km>
+    ...               obstime="2010/01/01T00:00:30")
+    >>> sc # doctest: +FLOAT_CMP
+    <SkyCoord (HeliographicCarrington: obstime=2010-01-01 00:00:30): (lon, lat, radius) in (deg, deg, km)
+        ( 1.,  2.,  3.)>
+
     >>> sc = SkyCoord([1,2,3]*u.deg, [4,5,6]*u.deg, [5,6,7]*u.km,
-    dateobs="2010/01/01T00:00:45", frame="heliographic_carrington")
-    >>> sc
-    <SkyCoord (HelioGraphicCarrington): dateobs=2010-01-01 00:00:45,
-    (lon, lat, rad) in (deg, deg, km)
-        [(1.0, 4.0, 5.0), (2.0, 5.0, 6.0), (3.0, 6.0, 7.0)]>
+    ...               obstime="2010/01/01T00:00:45", frame="heliographic_carrington")
+    >>> sc # doctest: +FLOAT_CMP
+    <SkyCoord (HeliographicCarrington: obstime=2010-01-01 00:00:45): (lon, lat, radius) in (deg, deg, km)
+        [( 1.,  4.,  5.), ( 2.,  5.,  6.), ( 3.,  6.,  7.)]>
     """
 
     name = "heliographic_carrington"
@@ -176,7 +180,7 @@ class HeliographicCarrington(HeliographicStonyhurst):
         ]
     }
 
-    dateobs = TimeFrameAttributeSunPy()
+    obstime = TimeFrameAttributeSunPy()
 
 
 class Heliocentric(BaseCoordinateFrame):
@@ -200,26 +204,32 @@ class Heliocentric(BaseCoordinateFrame):
         Y-axis coordinate, optional, must be keyword.
     z: `Quantity` object. Shared by both representations.
         Z-axis coordinate, optional, must be keyword.
-    D0: `Quantity` object.
-        Represents the distance between the observer and the Sun center.
-        Defaults to 1AU.
+    observer: `~sunpy.coordinates.frames.HeliographicStonyhurst`
+        The coordinate of the observer in the solar system.
+    obstime: SunPy Time
+        The date and time of the observation, used to convert to heliographic
+        carrington coordinates.
 
     Examples
     --------
+
     >>> from astropy.coordinates import SkyCoord, CartesianRepresentation
     >>> import sunpy.coordinates
     >>> import astropy.units as u
+
     >>> sc = SkyCoord(CartesianRepresentation(10*u.km, 1*u.km, 2*u.km),
-    ...               dateobs="2011/01/05T00:00:50", frame="heliocentric")
-    >>> sc
-    <SkyCoord (HelioCentric): dateobs=2011-01-05 00:00:50, D0=149597870.7 km,
-    x=10.0 km, y=1.0 km, z=2.0 km>
-    >>> sc = SkyCoord([1,2]*u.km, [3,4]*u.m, [5,6]*u.cm, frame="heliocentric",
-    dateobs="2011/01/01T00:00:54")
-    >>> sc
-    <SkyCoord (HelioCentric): dateobs=2011-01-01 00:00:54, D0=149597870.7 km,
-    (x, y, z) in (km, m, cm)
-        [(1.0, 3.0, 5.0), (2.0, 4.0, 6.0)]>
+    ...               obstime="2011/01/05T00:00:50", frame="heliocentric")
+    >>> sc # doctest: +FLOAT_CMP
+    <SkyCoord (Heliocentric: obstime=2011-01-05 00:00:50, observer=<HeliographicStonyhurst Coordinate (obstime=2011-01-05 00:00:50): (lon, lat, radius) in (deg, deg, AU)
+        ( 0., -3.43939103,  0.98334411)>): (x, y, z) in km
+        ( 10.,  1.,  2.)>
+
+    >>> sc = SkyCoord([1,2]*u.km, [3,4]*u.m, [5,6]*u.cm, frame="heliocentric", obstime="2011/01/01T00:00:54")
+
+    >>> sc # doctest: +FLOAT_CMP
+    <SkyCoord (Heliocentric: obstime=2011-01-01 00:00:54, observer=<HeliographicStonyhurst Coordinate (obstime=2011-01-01 00:00:54): (lon, lat, radius) in (deg, deg, AU)
+        ( 0., -2.97725356,  0.98335586)>): (x, y, z) in (km, m, cm)
+        [( 1.,  3.,  5.), ( 2.,  4.,  6.)]>
     """
 
     default_representation = CartesianRepresentation
@@ -228,11 +238,8 @@ class Heliocentric(BaseCoordinateFrame):
         'cylindrical': [RepresentationMapping('phi', 'psi', u.deg)]
     }
 
-    # d = FrameAttribute(default=(1*u.au).to(u.km))
-    D0 = Attribute(default=(1*u.au).to(u.km))
-    dateobs = TimeFrameAttributeSunPy()
-    L0 = Attribute(default=0*u.deg)
-    B0 = Attribute(default=0*u.deg)
+    obstime = TimeFrameAttributeSunPy()
+    observer = ObserverCoordinateAttribute(HeliographicStonyhurst, default="earth")
 
 
 class Helioprojective(BaseCoordinateFrame):
@@ -254,29 +261,32 @@ class Helioprojective(BaseCoordinateFrame):
         Y-axis coordinate.
     distance: `~astropy.units.Quantity`
         The radial distance from the observer to the coordinate point.
-    L0: `~astropy.coordinates.Angle`
-        The Heliographic (Stonyhurst) Longitude of the observer.
-    B0: `~astropy.coordinates.Angle` or `~astropy.units.Quantity`
-        The Heliographic (Stonyhurst) Latitude of the observer.
-    D0: `Quantity` object.
-        Represents the distance between observer and solar center.
-        **Defaults to 1 AU**.
+    obstime: SunPy Time
+        The date and time of the observation, used to convert to heliographic
+        carrington coordinates.
+    observer: `~sunpy.coordinates.frames.HeliographicStonyhurst`
+        The coordinate of the observer in the solar system.
+    rsun: `~astropy.units.Quantity`
+        The physical (length) radius of the Sun. Used to calculate the position
+        of the limb for calculating distance from the observer to the
+        coordinate.
 
     Examples
     --------
     >>> from astropy.coordinates import SkyCoord
     >>> import sunpy.coordinates
     >>> import astropy.units as u
-    >>> sc = SkyCoord(0*u.deg, 0*u.deg, 5*u.km, dateobs="2010/01/01T00:00:00",
+    >>> sc = SkyCoord(0*u.deg, 0*u.deg, 5*u.km, obstime="2010/01/01T00:00:00",
     ...               frame="helioprojective")
-    >>> sc
-    <SkyCoord (HelioProjective): dateobs=2010-01-01 00:00:00, D0=149597870.7 km
-    , Tx=0.0 arcsec, Ty=0.0 arcsec, distance=5.0 km>
-    >>> sc = SkyCoord(0*u.deg, 0*u.deg, dateobs="2010/01/01T00:00:00",
-    frame="helioprojective")
-    >>> sc
-    <SkyCoord (HelioProjective): dateobs=2010-01-01 00:00:00, D0=149597870.7 km
-    , Tx=0.0 arcsec, Ty=0.0 arcsec, distance=149597870.7 km>
+    >>> sc # doctest: +FLOAT_CMP
+    <SkyCoord (Helioprojective: obstime=2010-01-01 00:00:00, rsun=695508.0 km, observer=<HeliographicStonyhurst Coordinate (obstime=2010-01-01 00:00:00): (lon, lat, radius) in (deg, deg, AU)
+        ( 0., -3.00724817,  0.98330294)>): (Tx, Ty, distance) in (arcsec, arcsec, km)
+        ( 0.,  0.,  5.)>
+    >>> sc = SkyCoord(0*u.deg, 0*u.deg, obstime="2010/01/01T00:00:00", frame="helioprojective")
+    >>> sc # doctest: +FLOAT_CMP
+    <SkyCoord (Helioprojective: obstime=2010-01-01 00:00:00, rsun=695508.0 km, observer=<HeliographicStonyhurst Coordinate (obstime=2010-01-01 00:00:00): (lon, lat, radius) in (deg, deg, AU)
+        ( 0., -3.00724817,  0.98330294)>): (Tx, Ty) in arcsec
+        ( 0.,  0.)>
     """
 
     default_representation = SphericalWrap180Representation
@@ -302,11 +312,9 @@ class Helioprojective(BaseCoordinateFrame):
         ]
     }
 
-    D0 = Attribute(default=(1*u.au).to(u.km))
-    dateobs = TimeFrameAttributeSunPy()
-    L0 = Attribute(default=0*u.deg)
-    B0 = Attribute(default=0*u.deg)
+    obstime = TimeFrameAttributeSunPy()
     rsun = Attribute(default=RSUN_METERS.to(u.km))
+    observer = ObserverCoordinateAttribute(HeliographicStonyhurst, default="earth")
 
     def __init__(self, *args, **kwargs):
         _rep_kwarg = kwargs.get('representation', None)
@@ -330,7 +338,7 @@ class Helioprojective(BaseCoordinateFrame):
 
     def calculate_distance(self):
         """
-        This method calculates the third coordnate of the Helioprojective
+        This method calculates the third coordinate of the Helioprojective
         frame. It assumes that the coordinate point is on the disk of the Sun
         at the rsun radius.
 
@@ -346,12 +354,18 @@ class Helioprojective(BaseCoordinateFrame):
         if isinstance(self._data, SphericalRepresentation):
             return self
 
+        if not isinstance(self.observer, BaseCoordinateFrame):
+            raise ConvertError("Cannot calculate distance to the solar disk "
+                               "for observer '{}' "
+                               "without `obstime` being specified.".format(self.observer))
+
         rep = self.represent_as(UnitSphericalWrap180Representation)
         lat, lon = rep.lat, rep.lon
         alpha = np.arccos(np.cos(lat) * np.cos(lon)).to(lat.unit)
-        c = self.D0**2 - self.rsun**2
-        b = -2 * self.D0.to(u.m) * np.cos(alpha)
+        c = self.observer.radius**2 - self.rsun**2
+        b = -2 * self.observer.radius * np.cos(alpha)
         d = ((-1*b) - np.sqrt(b**2 - 4*c)) / 2
+
         return self.realize_frame(SphericalWrap180Representation(lon=lon,
                                                                  lat=lat,
                                                                  distance=d))
