@@ -1,3 +1,3 @@
 def get_package_data():
     return {'sunpy.data': ['sunpyrc'],
-            'sunpy.data.test': ['*.*', '*/*.*']}
+            'sunpy.data.test': ['*', '*/*']}
