@@ -498,8 +498,8 @@ def calculate_match_template_shift(mc, template=None, layer_index=0,
     for i, m in enumerate(mc.maps):
         # Calculate the shifts required in physical units, which are
         # presumed to be arcseconds.
-        xshift_arcseconds[i] = xshift_keep[i] * m.scale.x
-        yshift_arcseconds[i] = yshift_keep[i] * m.scale.y
+        xshift_arcseconds[i] = xshift_keep[i] * m.scale[0]
+        yshift_arcseconds[i] = yshift_keep[i] * m.scale[1]
 
     return {"x": xshift_arcseconds, "y": yshift_arcseconds}
 
@@ -596,8 +596,8 @@ def mapcube_coalign_by_match_template(mc, template=None, layer_index=0,
 
     # Calculate the pixel shifts
     for i, m in enumerate(mc):
-        xshift_keep[i] = (xshift_arcseconds[i] / m.scale.x)
-        yshift_keep[i] = (yshift_arcseconds[i] / m.scale.y)
+        xshift_keep[i] = (xshift_arcseconds[i] / m.scale[0])
+        yshift_keep[i] = (yshift_arcseconds[i] / m.scale[1])
 
     # Apply the shifts and return the coaligned mapcube
     return apply_shifts(mc, -yshift_keep, -xshift_keep, clip=clip, **kwargs)
