@@ -7,6 +7,9 @@ import astropy.units as u
 
 from sunpy.map.sources.sdo import AIAMap
 
+__all__ = ['aiaprep']
+
+
 def aiaprep(aiamap):
     """
     Processes a level 1 `~sunpy.map.sources.sdo.AIAMap` into a level 1.5
@@ -44,11 +47,11 @@ def aiaprep(aiamap):
 
     # Target scale is 0.6 arcsec/pixel, but this needs to be adjusted if the map
     # has already been rescaled.
-    if (aiamap.scale.x/0.6).round() != 1.0*u.arcsec and aiamap.data.shape != (4096, 4096):
-        scale = (aiamap.scale.x/0.6).round() * 0.6*u.arcsec
+    if (aiamap.scale[0] / 0.6).round() != 1.0 * u.arcsec and aiamap.data.shape != (4096, 4096):
+        scale = (aiamap.scale[0] / 0.6).round() * 0.6 * u.arcsec
     else:
-        scale = 0.6*u.arcsec # pragma: no cover # can't test this because it needs a full res image
-    scale_factor = aiamap.scale.x / scale
+        scale = 0.6 * u.arcsec  # pragma: no cover # can't test this because it needs a full res image
+    scale_factor = aiamap.scale[0] / scale
 
     tempmap = aiamap.rotate(recenter=True, scale=scale_factor.value, missing=aiamap.min())
 
@@ -56,7 +59,8 @@ def aiaprep(aiamap):
     # crpix1 and crpix2 will be equal (recenter=True), as aiaprep does not work with submaps
     center = np.floor(tempmap.meta['crpix1'])
     range_side = (center + np.array([-1, 1]) * aiamap.data.shape[0] / 2) * u.pix
-    newmap = tempmap.submap(range_side, range_side)
+    newmap = tempmap.submap(u.Quantity([range_side[0], range_side[0]]),
+                            u.Quantity([range_side[1], range_side[1]]))
 
     newmap.meta['r_sun'] = newmap.meta['rsun_obs'] / newmap.meta['cdelt1']
     newmap.meta['lvl_num'] = 1.5
