@@ -1,7 +1,6 @@
 from __future__ import absolute_import
 from __future__ import division
 
-
 import os
 import copy
 from sunpy.extern.six.moves import urllib
@@ -19,20 +18,22 @@ from sunpy import sun
 from sunpy.io.fits import fits
 
 __all__ = ['download_weekly_pointing_file', 'get_detector_sun_angles_for_time',
-            'get_detector_sun_angles_for_date','plot_detector_sun_angles',
-             'met_to_utc']
+           'get_detector_sun_angles_for_date', 'plot_detector_sun_angles',
+           'met_to_utc']
+
 
 def download_weekly_pointing_file(date):
     """
-    Downloads the FERMI/LAT weekly pointing file corresponding to the specified date.
-    This file contains 1 minute cadence data on the spacecraft pointing, useful for
-    calculating detector angles.
+    Downloads the FERMI/LAT weekly pointing file corresponding to the specified
+    date. This file contains 1 minute cadence data on the spacecraft pointing,
+    useful for calculating detector angles.
 
     Parameters
     ----------
 
     date : `datetime.datetime`
-        A datetime object or other date format understood by the parse_time function.
+        A datetime object or other date format understood by the parse_time
+        function.
     """
 
     date = parse_time(date)
@@ -41,7 +42,7 @@ def download_weekly_pointing_file(date):
     # use Fermi data server to access weekly LAT pointing file.
     base_url = 'ftp://legacy.gsfc.nasa.gov/FTP/glast/data/lat/weekly/spacecraft/'
     fbasename = 'lat_spacecraft_weekly_w'
-    
+
     # find out which file to get based on date
     # earliest full file in the FERMI server is for mission week 10,
     # beginning 2008 August 7.
@@ -49,17 +50,17 @@ def download_weekly_pointing_file(date):
     base_week = 10
 
     # find out which mission week corresponds to date
-    time_diff = date-weekly_file_start
-    weekdiff = time_diff.days//7
+    time_diff = date - weekly_file_start
+    weekdiff = time_diff.days // 7
     week = weekdiff + base_week
-   # weekstr = ('%03.0f' % week)
+    # weekstr = ('%03.0f' % week)
     weekstr = '{:03.0f}'.format(week)
 
     # construct the full url for the weekly pointing file
     full_fname = fbasename + weekstr + '_p202_v001.fits'
     pointing_file_url = base_url + full_fname
 
-    #try to download the file from the FTP site
+    # try to download the file from the FTP site
     try:
         resp = urllib.request.urlopen(pointing_file_url)
         exists = True
@@ -72,8 +73,8 @@ def download_weekly_pointing_file(date):
         raise ValueError('No Fermi pointing files found for given date!')
 
     # download the file
-    destination=os.path.join(tmp_dir,full_fname)
-    urllib.request.urlretrieve(pointing_file_url,destination)
+    destination = os.path.join(tmp_dir, full_fname)
+    urllib.request.urlretrieve(pointing_file_url, destination)
 
     # return the location of the downloaded file
     return destination
@@ -87,7 +88,8 @@ def get_detector_sun_angles_for_time(time, file):
     ----------
 
     time : `datetime.datetime`
-        A datetime object or other time format understood by the parse_time function.
+        A datetime object or other time format understood by the parse_time
+        function.
     file : `str`
         A filepath to a Fermi/LAT weekly pointing file (e.g. as obtained by the
         download_weekly_pointing_file function).
@@ -110,20 +112,23 @@ def get_detector_sun_angles_for_time(time, file):
     sun_pos = [sunpos_ra_not_in_deg[0].to('deg'), sunpos_ra_not_in_deg[1]]
     # sun_pos = [(sunpos_ra_not_in_deg[0] / 24) * 360., sunpos_ra_not_in_deg[1]]
     # now get the angle between each detector and the Sun
-    detector_to_sun_angles = (get_detector_separation_angles(detector_radecs, sun_pos))
+    detector_to_sun_angles = (get_detector_separation_angles(detector_radecs,
+                                                             sun_pos))
 
     return detector_to_sun_angles
 
 
 def get_detector_sun_angles_for_date(date, file):
     """
-    get the GBM detector angles vs the sun as a function of time for a given date
+    get the GBM detector angles vs the sun as a function of time for a given
+    date
 
     Parameters
     ----------
 
     date : `datetime.datetime`
-        A datetime object or other date format understood by the parse_time function.
+        A datetime object or other date format understood by the parse_time
+        function.
     file : `str`
         A filepath to a Fermi/LAT weekly pointing file (e.g. as obtained by the
         download_weekly_pointing_file function).
@@ -140,7 +145,8 @@ def get_detector_sun_angles_for_date(date, file):
     # get the detector vs Sun angles for each t and store in a list of
     # dictionaries.
     for i in range(len(scx)):
-        detector_radecs = nai_detector_radecs(detectors, scx[i], scz[i], times[i])
+        detector_radecs = nai_detector_radecs(detectors, scx[i], scz[i],
+                                              times[i])
 
         # this gets the sun position with RA in hours in decimal format
         # (e.g. 4.3). DEC is already in degrees
@@ -149,12 +155,14 @@ def get_detector_sun_angles_for_date(date, file):
         # now Sun position with RA in degrees
         sun_pos = [sunpos_ra_not_in_deg[0].to('deg'), sunpos_ra_not_in_deg[1]]
         # now get the angle between each detector and the Sun
-        detector_to_sun_angles.append(get_detector_separation_angles(detector_radecs, sun_pos))
+        detector_to_sun_angles.append(
+            get_detector_separation_angles(detector_radecs, sun_pos))
 
     # slice the list of dictionaries to get the angles for each detector in a
     # list form
     angles = OrderedDict()
-    key_list = ['n0','n1','n2','n3','n4','n5','n6','n7','n8','n9','n10','n11','time']
+    key_list = ['n0', 'n1', 'n2', 'n3', 'n4', 'n5', 'n6', 'n7', 'n8', 'n9',
+                'n10', 'n11', 'time']
     for i in range(13):
         if not key_list[i] == 'time':
             angles[key_list[i]] = [item[key_list[i]].value
@@ -183,10 +191,12 @@ def plot_detector_sun_angles(angles):
     figure = plt.figure(1)
     for n in angles.keys():
         if not n == 'time':
-            plt.plot(angles['time'],angles[n].value,
-                     label = '{lab} ({val})' .format(lab=n,
-                     val = str(np.mean(angles[n].value))[0:5]))
-    plt.ylim(180,0)
+            plt.plot(
+                angles['time'],
+                angles[n].value,
+                label='{lab} ({val})'.format(
+                    lab=n, val=str(np.mean(angles[n].value))[0:5]))
+    plt.ylim(180, 0)
     plt.ylabel('angle (degrees)')
     plt.xlabel('Start time: ' + angles['time'][0].isoformat())
     plt.title('Detector pointing angle from Sun')
@@ -217,10 +227,10 @@ def get_scx_scz_at_time(time, file):
         timesinutc.append(met_to_utc(tim))
     ind = np.searchsorted(timesinutc, time)
 
-    scx_radec = (Longitude(hdulist[1].data['RA_SCX'][ind]*u.deg),
-                 Latitude(hdulist[1].data['DEC_SCX'][ind]*u.deg))
-    scz_radec = (Longitude(hdulist[1].data['RA_SCZ'][ind]*u.deg),
-                 Latitude(hdulist[1].data['DEC_SCZ'][ind]*u.deg))
+    scx_radec = (Longitude(hdulist[1].data['RA_SCX'][ind] * u.deg),
+                 Latitude(hdulist[1].data['DEC_SCX'][ind] * u.deg))
+    scz_radec = (Longitude(hdulist[1].data['RA_SCZ'][ind] * u.deg),
+                 Latitude(hdulist[1].data['DEC_SCZ'][ind] * u.deg))
 
     return scx_radec, scz_radec, timesinutc[ind]
 
@@ -251,10 +261,10 @@ def get_scx_scz_in_timerange(timerange, file):
     scx_radec = []
     scz_radec = []
     for i in range(startind, endind):
-        scx_radec.append((Longitude(hdulist[1].data['RA_SCX'][i]*u.deg),
-                          Latitude(hdulist[1].data['DEC_SCX'][i]*u.deg)))
-        scz_radec.append((Longitude(hdulist[1].data['RA_SCZ'][i]*u.deg),
-                          Latitude(hdulist[1].data['DEC_SCZ'][i]*u.deg)))
+        scx_radec.append((Longitude(hdulist[1].data['RA_SCX'][i] * u.deg),
+                          Latitude(hdulist[1].data['DEC_SCX'][i] * u.deg)))
+        scz_radec.append((Longitude(hdulist[1].data['RA_SCZ'][i] * u.deg),
+                          Latitude(hdulist[1].data['DEC_SCZ'][i] * u.deg)))
     return scx_radec, scz_radec, timesinutc[startind:endind]
 
 
@@ -267,19 +277,18 @@ def nai_detector_angles():
     """
 
     # angles listed as [azimuth, zenith]
-    detectors = {'n0': [45.89*u.deg, 20.58*u.deg],
-                 'n1': [45.11*u.deg, 45.31*u.deg],
-                 'n2': [58.44*u.deg, 90.21*u.deg],
-                 'n3': [314.87*u.deg, 45.24*u.deg],
-                 'n4': [303.15*u.deg, 90.27*u.deg],
-                 'n5': [3.35*u.deg, 89.79*u.deg],
-                 'n6': [224.93*u.deg, 20.43*u.deg],
-                 'n7': [224.62*u.deg, 46.18*u.deg],
-                 'n8': [236.61*u.deg, 89.97*u.deg],
-                 'n9': [135.19*u.deg, 45.55*u.deg],
-                 'n10': [123.73*u.deg, 90.42*u.deg],
-                 'n11': [183.74*u.deg, 90.32*u.deg]
-                 }
+    detectors = {'n0': [45.89 * u.deg, 20.58 * u.deg],
+                 'n1': [45.11 * u.deg, 45.31 * u.deg],
+                 'n2': [58.44 * u.deg, 90.21 * u.deg],
+                 'n3': [314.87 * u.deg, 45.24 * u.deg],
+                 'n4': [303.15 * u.deg, 90.27 * u.deg],
+                 'n5': [3.35 * u.deg, 89.79 * u.deg],
+                 'n6': [224.93 * u.deg, 20.43 * u.deg],
+                 'n7': [224.62 * u.deg, 46.18 * u.deg],
+                 'n8': [236.61 * u.deg, 89.97 * u.deg],
+                 'n9': [135.19 * u.deg, 45.55 * u.deg],
+                 'n10': [123.73 * u.deg, 90.42 * u.deg],
+                 'n11': [183.74 * u.deg, 90.32 * u.deg]}
 
     return detectors
 
@@ -315,13 +324,15 @@ def nai_detector_radecs(detectors, scx, scz, time):
         the given input time.
     """
 
-    scx_vector = (np.array([np.cos(scx[0].to('rad').value)*np.cos(scx[1].to('rad').value),
-                  np.sin(scx[0].to('rad').value)*np.cos(scx[1].to('rad').value),
-                  np.sin(scx[1].to('rad').value)]))
+    scx_vector = (np.array(
+        [np.cos(scx[0].to('rad').value) * np.cos(scx[1].to('rad').value),
+         np.sin(scx[0].to('rad').value) * np.cos(scx[1].to('rad').value),
+         np.sin(scx[1].to('rad').value)]))
 
-    scz_vector = (np.array([np.cos(scz[0].to('rad').value)*np.cos(scz[1].to('rad').value),
-                  np.sin(scz[0].to('rad').value)*np.cos(scz[1].to('rad').value),
-                  np.sin(scz[1].to('rad').value)]))
+    scz_vector = (np.array(
+        [np.cos(scz[0].to('rad').value) * np.cos(scz[1].to('rad').value),
+         np.sin(scz[0].to('rad').value) * np.cos(scz[1].to('rad').value),
+         np.sin(scz[1].to('rad').value)]))
 
     # For each detector, do the rotation depending on the detector zenith and
     # azimuth angles.
@@ -340,7 +351,8 @@ def nai_detector_radecs(detectors, scx, scz, time):
         vz_primed = rotate_vector(scz_vector, vy_primed, np.deg2rad(theta))
 
         # now we should be pointing at the new RA/DEC.
-        ra = Longitude(np.degrees(np.arctan2(vz_primed[1], vz_primed[0])) * u.deg)
+        ra = Longitude(
+            np.degrees(np.arctan2(vz_primed[1], vz_primed[0])) * u.deg)
         dec = Latitude(np.degrees(np.arcsin(vz_primed[2])) * u.deg)
 
         # save the RA/DEC in a dictionary
@@ -368,13 +380,16 @@ def rotate_vector(vector, axis, theta):
     http://en.wikipedia.org/wiki/Euler-Rodrigues_parameters#Rotation_angle_and_rotation_axis
     """
 
-    axis = axis/np.sqrt(np.dot(axis, axis))
-    a = np.cos(theta/2)
-    b, c, d = -axis*np.sin(theta/2)
+    axis = axis / np.sqrt(np.dot(axis, axis))
+    a = np.cos(theta / 2)
+    b, c, d = -axis * np.sin(theta / 2)
 
-    rot_matrix = np.array([[a*a+b*b-c*c-d*d, 2*(b*c+a*d),2*(b*d-a*c)],
-                 [2*(b*c-a*d), a*a+c*c-b*b-d*d, 2*(c*d+a*b)],
-                 [2*(b*d+a*c), 2*(c*d-a*b), a*a+d*d-b*b-c*c]])
+    rot_matrix = np.array(
+        [[a * a + b * b - c * c - d * d, 2 * (b * c + a * d), 2 *
+          (b * d - a * c)], [2 * (b * c - a * d), a * a + c * c - b * b - d *
+                             d, 2 * (c * d + a * b)],
+         [2 * (b * d + a * c), 2 * (c * d - a * b), a * a + d * d - b * b - c *
+          c]])
 
     return np.dot(rot_matrix, vector)
 
@@ -393,7 +408,7 @@ def get_detector_separation_angles(detector_radecs, sunpos):
             Two-element list containing the RA/DEC of the Sun position as
             AstroPy Quantities, e.g. [<Longitude 73.94 deg>,
             <Latitude 22.66 deg>]
-    
+
     """
     angles = copy.deepcopy(detector_radecs)
     for l, d in detector_radecs.items():
@@ -420,11 +435,12 @@ def separation_angle(radec1, radec2):
 
     """
 
-    cosine_of_angle = (( np.cos( ((90*u.deg) - radec1[1].to('degree')).to('rad')) *
-                        np.cos( (90*u.deg - radec2[1].to('degree')).to('rad')) )
-                        + ( np.sin( ((90*u.deg) - radec1[1].to('degree')).to('rad') ) *
-                        np.sin( ((90*u.deg) - radec2[1].to('degree')).to('rad') ) *
-                      np.cos( (radec1[0].to('degree') - radec2[0].to('degree')).to('rad')   ) ) )
+    cosine_of_angle = (
+        (np.cos(((90 * u.deg) - radec1[1].to('degree')).to('rad')) *
+         np.cos((90 * u.deg - radec2[1].to('degree')).to('rad'))) +
+        (np.sin(((90 * u.deg) - radec1[1].to('degree')).to('rad')) *
+         np.sin(((90 * u.deg) - radec2[1].to('degree')).to('rad')) *
+         np.cos((radec1[0].to('degree') - radec2[0].to('degree')).to('rad'))))
 
     angle = (np.arccos(cosine_of_angle)).to('degree')
 
@@ -450,11 +466,13 @@ def met_to_utc(timeinsec):
     # Times for GBM are in Mission Elapsed Time (MET).
     # The reference time for this is 2001-Jan-01 00:00.
     met_ref_time = parse_time('2001-01-01 00:00')
-    offset_from_utc = (met_ref_time - parse_time('1979-01-01 00:00')).total_seconds()
+    offset_from_utc = (
+        met_ref_time - parse_time('1979-01-01 00:00')).total_seconds()
     time_in_utc = parse_time(timeinsec + offset_from_utc)
 
     return time_in_utc
 
+
 def utc_to_met(time_ut):
     """
     Converts a UT (in datetime format) to a Fermi Mission Elapsed Time (MET) float.
@@ -472,7 +490,8 @@ def utc_to_met(time_ut):
     """
     met_ref_time = parse_time('2001-01-01 00:00')
     ut_seconds = (time_ut - parse_time('1979-01-01')).total_seconds()
-    offset_from_utc = (met_ref_time - parse_time('1979-01-01 00:00')).total_seconds()
+    offset_from_utc = (
+        met_ref_time - parse_time('1979-01-01 00:00')).total_seconds()
     fermi_met = ut_seconds - offset_from_utc
 
     return fermi_met
