@@ -21,7 +21,7 @@ LONGFLUX = Quantity([7e-6], unit="W/m**2")
 SHORTFLUX = Quantity([7e-7], unit="W/m**2")
 DATE = "2014-04-16"
 
-@pytest.mark.online
+@pytest.mark.remote_data
 def test_goes_event_list():
     # Set a time range to search
     trange = TimeRange('2011-06-07 00:00', '2011-06-08 00:00')
@@ -63,7 +63,7 @@ def test_goes_event_list():
     assert result[0]['noaa_active_region'] == 11226
 
 
-@pytest.mark.online
+@pytest.mark.remote_data
 def test_calculate_temperature_em():
     # Create GOESLightcurve object, then create new one with
     # temperature & EM using with calculate_temperature_em().
@@ -89,7 +89,7 @@ def test_calculate_temperature_em():
     del goeslc_revert.data["em"]
     assert_frame_equal(goeslc_revert.data, goeslc.data)
 
-@pytest.mark.online
+@pytest.mark.remote_data
 def test_goes_chianti_tem_errors():
     # Define input variables.
     ratio = SHORTFLUX/LONGFLUX
@@ -133,7 +133,7 @@ def test_goes_chianti_tem_errors():
     with pytest.raises(ValueError):
         em = goes._goes_get_chianti_em(LONGFLUX, temp_test_toobig)
 
-@pytest.mark.online
+@pytest.mark.remote_data
 def test_goes_chianti_tem_case1():
     # test case 1: satellite > 7, abundances = coronal
     temp1, em1 = goes._goes_chianti_tem(LONGFLUX, SHORTFLUX, satellite=15,
@@ -142,7 +142,7 @@ def test_goes_chianti_tem_case1():
     assert all(em1 < Quantity([4.79e+48], unit="1/cm**3")) and \
       em1 > Quantity([4.78e+48], unit="1/cm**3")
 
-@pytest.mark.online
+@pytest.mark.remote_data
 def test_goes_chianti_tem_case2():
     # test case 2: satellite > 7, abundances = photospheric
     temp2, em2 = goes._goes_chianti_tem(LONGFLUX, SHORTFLUX, satellite=15,
@@ -152,7 +152,7 @@ def test_goes_chianti_tem_case2():
     assert all(em2 < Quantity([1.12e+49], unit="1/cm**3")) and \
       all(em2 > Quantity([1.11e+49], unit="1/cm**3"))
 
-@pytest.mark.online
+@pytest.mark.remote_data
 def test_goes_chianti_tem_case3():
     # test case 3: satellite < 8 and != 6, abundances = coronal
     temp3, em3 = goes._goes_chianti_tem(LONGFLUX, SHORTFLUX, satellite=5,
@@ -163,7 +163,7 @@ def test_goes_chianti_tem_case3():
     assert all(em3 < Quantity([3.85e+48], unit="1/cm**3")) and \
       all(em3 > Quantity([3.84e+48], unit="1/cm**3"))
 
-@pytest.mark.online
+@pytest.mark.remote_data
 def test_goes_chianti_tem_case4():
     # test case 4: satellite < 8 and != 6, abundances = photospheric
     temp4, em4 = goes._goes_chianti_tem(LONGFLUX, SHORTFLUX, satellite=5,
@@ -174,7 +174,7 @@ def test_goes_chianti_tem_case4():
     assert all(em4 < Quantity(8.81e+48, unit="1/cm**3")) and \
       all(em4 > Quantity(8.80e+48, unit="1/cm**3"))
 
-@pytest.mark.online
+@pytest.mark.remote_data
 def test_goes_chianti_tem_case5():
     # test case 5: satellite = 6, date < 1983-06-28, abundances = coronal
     temp5, em5 = goes._goes_chianti_tem(LONGFLUX, SHORTFLUX, satellite=6,
@@ -185,7 +185,7 @@ def test_goes_chianti_tem_case5():
     assert all(em5 < Quantity(3.13e+48, unit="1/cm**3")) and \
       all(em5 > Quantity(3.12e+48, unit="1/cm**3"))
 
-@pytest.mark.online
+@pytest.mark.remote_data
 def test_goes_chianti_tem_case6():
     # test case 6: satellite = 6, date < 1983-06-28, abundances = photospheric
     temp6, em6 = goes._goes_chianti_tem(LONGFLUX, SHORTFLUX, satellite=6,
@@ -196,7 +196,7 @@ def test_goes_chianti_tem_case6():
     assert all(em6 < Quantity(6.74e+48, unit="1/cm**3")) and \
       all(em6 > Quantity(6.73e+48, unit="1/cm**3"))
 
-@pytest.mark.online
+@pytest.mark.remote_data
 def test_goes_chianti_tem_case7():
     # test case 7: satellite = 6, date > 1983-06-28, abundances = coronal
     temp7, em7 = goes._goes_chianti_tem(LONGFLUX, SHORTFLUX, satellite=6,
@@ -207,7 +207,7 @@ def test_goes_chianti_tem_case7():
     assert all(em7 < Quantity(4.08e+48, unit="1/cm**3")) and \
       all(em7 > Quantity(4.07e+48, unit="1/cm**3"))
 
-@pytest.mark.online
+@pytest.mark.remote_data
 def test_goes_chianti_tem_case8():
     # test case 8: satellite = 6, date > 1983-06-28, abundances = photospheric
     temp8, em8 = goes._goes_chianti_tem(LONGFLUX, SHORTFLUX, satellite=6,
@@ -218,7 +218,7 @@ def test_goes_chianti_tem_case8():
     assert all(em8 < Quantity(9.39e+48, unit="1/cm**3")) and \
       all(em8 > Quantity(9.38e+48, unit="1/cm**3"))
 
-@pytest.mark.online
+@pytest.mark.remote_data
 def test_calculate_radiative_loss_rate():
     # Define input variables.
     goeslc_input = lightcurve.GOESLightCurve.create("2014-01-01 00:00:00",
@@ -245,7 +245,7 @@ def test_calculate_radiative_loss_rate():
     goes_test = goes.calculate_radiative_loss_rate(goeslc_no_em)
     assert_frame_equal(goeslc_test.data, goeslc_expected.data)
 
-@pytest.mark.online
+@pytest.mark.remote_data
 def test_calc_rad_loss_errors():
     # Define input variables
     temp = 11.0 * Quantity(np.ones(6), unit="MK")
@@ -282,7 +282,7 @@ def test_calc_rad_loss_errors():
     with pytest.raises(ValueError):
         rad_loss_test = goes._calc_rad_loss(temp, em, obstime_nonchrono)
 
-@pytest.mark.online
+@pytest.mark.remote_data
 def test_calc_rad_loss_nokwags():
     # Define input variables
     temp = Quantity([11.0, 11.0, 11.0, 11.0, 11.0, 11.0], unit="MK")
@@ -302,7 +302,7 @@ def test_calc_rad_loss_nokwags():
     assert_quantity_allclose(rad_loss_test["rad_loss_rate"],
                        rad_loss_expected["rad_loss_rate"], rtol=0.01)
 
-@pytest.mark.online
+@pytest.mark.remote_data
 def test_calc_rad_loss_obstime():
     # Define input variables
     temp = Quantity([11.0, 11.0, 11.0, 11.0, 11.0, 11.0], unit="MK")
@@ -331,7 +331,7 @@ def test_calc_rad_loss_obstime():
     assert_quantity_allclose(rad_loss_test["rad_loss_cumul"],
                        rad_loss_expected["rad_loss_cumul"], rtol=0.0001)
 
-@pytest.mark.online
+@pytest.mark.remote_data
 def test_calculate_xray_luminosity():
     # Check correct exceptions are raised to incorrect inputs
     not_goeslc = []
