@@ -33,6 +33,9 @@ References
 from __future__ import absolute_import, division, print_function
 import os
 import re
+import sys
+import warnings
+import traceback
 import itertools
 import collections
 
@@ -46,6 +49,9 @@ __all__ = ['read', 'get_header', 'write', 'extract_waveunit']
 __author__ = "Keith Hughitt, Stuart Mumford, Simon Liedtke"
 __email__ = "keith.hughitt@nasa.gov"
 
+HDPair = collections.namedtuple('HDPair', ['data', 'header'])
+
+
 def read(filepath, hdus=None, memmap=None, **kwargs):
     """
     Read a fits file
@@ -69,24 +75,32 @@ def read(filepath, hdus=None, memmap=None, **kwargs):
     Also all comments in the original file are concatenated into a single
     'comment' key in the returned FileHeader.
     """
-    hdulist = fits.open(filepath, memmap=memmap)
-    if hdus is not None:
-        if isinstance(hdus, int):
-            hdulist = hdulist[hdus]
-        elif isinstance(hdus, collections.Iterable):
-            hdulist = [hdulist[i] for i in hdus]
-    try:
+    with fits.open(filepath, ignore_blank=True, memmap=memmap) as hdulist:
+        if hdus is not None:
+            if isinstance(hdus, int):
+                hdulist = hdulist[hdus]
+            elif isinstance(hdus, collections.Iterable):
+                hdulist = [hdulist[i] for i in hdus]
+
         hdulist.verify('silentfix+warn')
 
         headers = get_header(hdulist)
         pairs = []
-        for hdu,header in zip(hdulist, headers):
-            pairs.append((hdu.data, header))
-    finally:
-        hdulist.close()
+
+        for i, (hdu, header) in enumerate(zip(hdulist, headers)):
+            try:
+                pairs.append(HDPair(hdu.data, header))
+            except (KeyError, ValueError) as e:
+                message = "Error when reading HDU {}. Skipping.\n".format(i)
+                for line in traceback.format_tb(sys.exc_info()[2]):
+                    message += line
+                    message += '\n'
+                message += repr(e)
+                warnings.warn(message, Warning, stacklevel=2)
 
     return pairs
 
+
 def get_header(afile):
     """
     Read a fits file and return just the headers for all HDU's. In each header,
@@ -103,13 +117,13 @@ def get_header(afile):
     headers : `list`
         A list of FileHeader headers.
     """
-    if isinstance(afile,fits.HDUList):
+    if isinstance(afile, fits.HDUList):
         hdulist = afile
         close = False
     else:
-        hdulist = fits.open(afile)
+        hdulist = fits.open(afile, ignore_blank=True)
         hdulist.verify('silentfix')
-        close=True
+        close = True
 
     try:
         headers= []
@@ -141,6 +155,7 @@ def get_header(afile):
             hdulist.close()
     return headers
 
+
 def write(fname, data, header, **kwargs):
     """
     Take a data header pair and write a FITS file.
@@ -216,6 +231,7 @@ def extract_waveunit(header):
     directly passed to ``astropy.units.Unit``::
 
         >>> import astropy.units
+        >>> header = {'WAVEUNIT': 'Angstrom', 'KEYCOMMENTS': {}}
         >>> waveunit = extract_waveunit(header)
         >>> if waveunit is not None:
         ...     unit = astropy.units.Unit(waveunit)
