@@ -9,11 +9,11 @@ import numpy as np
 from sunpy.lightcurve import LightCurve
 from scipy.ndimage import label
 from sunpy.time import TimeRange
+from sunpy.extern.six.moves import range
 
 __all__ = ['LogicalLightCurve']
 
-#
-#
+
 # Logical Lightcurve
 # TODO
 # Change the init to accept a list of TimeRange objects.  Durations between the
@@ -35,7 +35,7 @@ class LogicalLightCurve(LightCurve):
     def complement(self):
         """Return the logical complement of the original lightcurve."""
         return LogicalLightCurve.create(np.invert(self.data),
-                                        header = self.header)
+                                        header=self.header)
 
     def times(self):
         """Returns a list of time ranges where values are True.
@@ -48,8 +48,8 @@ class LogicalLightCurve(LightCurve):
 
         labeling = label(self.data)
         timeranges = []
-        for i in xrange(1, labeling[1]+1):
+        for i in range(1, labeling[1] + 1):
             eventindices = (labeling[0] == i).nonzero()
-            timeranges.append( TimeRange(self.data.index[ eventindices[0][0] ],
-                                         self.data.index[ eventindices[0][-1] ]) )
+            timeranges.append(TimeRange(self.data.index[eventindices[0][0]],
+                                        self.data.index[eventindices[0][-1]]))
         return timeranges
