@@ -14,28 +14,28 @@ __all__ = ['NOAAIndicesLightCurve', 'NOAAPredictIndicesLightCurve']
 
 
 class NOAAIndicesLightCurve(LightCurve):
-    """NOAA Solar Cycle monthly indices.
-
+    """
+    NOAA Solar Cycle monthly indices.
     Solar activity is measured by a number of different values. The NOAA Solar
     Weather Prediction Center (SWPC) publishes the following indices. All of
     these indices are also provided as a 13-month running smoothed value.
 
-    * The SWO sunspot number is issued by the NOAA Space Weather
-      Prediction Center (SWPC)
-    * The RI sunspot number is the official International Sunspot Number and is
-      issued by the `Solar Influence Data Analysis Center (SDIC)
-      <http://sidc.oma.be>`_ in Brussels, Belgium.
-    * The ratio between the SWO and RI indices.
-    * Radio flux at 10.7 cm is produced by
-      `Penticon/Ottawa <http://www.ngdc.noaa.gov/stp/solar/flux.html>`_ and the
-      units are in sfu.
-    * The Ap Geomagnetic Index is produced by the United States Air Force (USAF).
+
+    1. The SWO sunspot number is issued by the NOAA Space Weather Prediction Center (SWPC)
+    2. The RI sunspot number is the official International Sunspot Number and is issued by
+       the `Solar Influence Data Analysis Center (SDIC) <http://sidc.oma.be>`_ in Brussels, Belgium.
+    3. The ratio between the SWO and RI indices.
+    4. Radio flux at 10.7 cm is produced by Penticon/Ottawa <http://www.ngdc.noaa.gov/stp/solar/flux.html>
+       and the units are in sfu.
+    5. The Ap Geomagnetic Index is produced by the United States Air Force (USAF).
+
+
 
     Examples
     --------
     >>> from sunpy import lightcurve as lc
-    >>> noaa = lc.NOAAIndicesLightCurve.create()
-    >>> noaa.peek()   # doctest: +SKIP
+    >>> noaa = lc.NOAAIndicesLightCurve.create()  # doctest: +REMOTE_DATA
+    >>> noaa.peek()  # doctest: +SKIP
 
     References
     ----------
@@ -44,16 +44,19 @@ class NOAAIndicesLightCurve(LightCurve):
     * `Indices Descriptions <ftp://ftp.swpc.noaa.gov/pub/weekly/README3>`_
     * `NOAA plots of Solar Cycle Progression <http://www.swpc.noaa.gov/products/solar-cycle-progression>`_
     * `NOAA Product List <http://www.swpc.noaa.gov/products-and-data>`_
+
+
     """
+    default_url_noaa_indices = "ftp://ftp.swpc.noaa.gov/pub/weekly/RecentIndices.txt"
 
     def peek(self, type='sunspot SWO', **plot_args):
         """Plots NOAA Indices as a function of time. An example is shown below.
 
-        .. plot::
+        ..plot::
 
             from sunpy import lightcurve as lc
-            from sunpy.data.sample import NOAAINDICES_LIGHTCURVE
-            noaa = lc.NOAAIndicesLightCurve.create(NOAAINDICES_LIGHTCURVE)
+            from sunpy.data.sample import NOAAINDICES_TIMESERIES
+            noaa = lc.NOAAIndicesLightCurve.create(NOAAINDICES_TIMESERIES)
             noaa.peek()
 
         Parameters
@@ -62,13 +65,13 @@ class NOAAIndicesLightCurve(LightCurve):
             The type of plot required.
 
         **plot_args : dict
-            Any additional plot arguments that should be used
-            when plotting.
+            Any additional plot arguments that should be used when plotting.
 
         Returns
         -------
-        fig : `~matplotlib.Figure`
+        fig : ~matplotlib.Figure
             A plot figure.
+
         """
 
         figure = plt.figure()
@@ -108,12 +111,12 @@ class NOAAIndicesLightCurve(LightCurve):
     @classmethod
     def _get_default_uri(cls):
         """Return the url to download indices"""
-        return "ftp://ftp.swpc.noaa.gov/pub/weekly/RecentIndices.txt"
+        return NOAAIndicesLightCurve.default_url_noaa_indices
 
     @staticmethod
     def _get_url_for_date_range(*args, **kwargs):
         """Returns a URL for the specified date."""
-        return NOAAIndicesLightCurve._get_default_uri()
+        return NOAAIndicesLightCurve.default_url_noaa_indices
 
     @staticmethod
     def _parse_csv(filepath):
@@ -136,25 +139,25 @@ class NOAAIndicesLightCurve(LightCurve):
             return {'comments': header}, data
 
 class NOAAPredictIndicesLightCurve(LightCurve):
-    """NOAA Solar Cycle Predicted Progression
-
+    """
+    NOAA Solar Cycle Predicted Progression
     The predictions are updated monthly and are produced by ISES. Observed
     values are initially the preliminary values which are replaced with the
     final values as they become available.
 
     The following predicted values are available.
-
     * The predicted RI sunspot number is the official International Sunspot
-      Number and is issued by the `Solar Influence Data Analysis Center (SDIC) <http://sidc.oma.be>`_ in Brussels, Belgium.
+    Number and is issued by the `Solar Influence Data Analysis Center (SDIC) <http://sidc.oma.be>`_ in Brussels, Belgium.
     * The predicted radio flux at 10.7 cm is produced by
-      `Penticon/Ottawa <http://www.ngdc.noaa.gov/stp/solar/flux.html>`_ and the units are in sfu.
+    `Penticon/Ottawa <http://www.ngdc.noaa.gov/stp/solar/flux.html>`_ and the units are in sfu.
 
     Examples
     --------
     >>> from sunpy import lightcurve as lc
-    >>> noaa = lc.NOAAPredictIndicesLightCurve.create()
+    >>> noaa = lc.NOAAPredictIndicesLightCurve.create()  #doctest: +REMOTE_DATA
     >>> noaa.peek()   # doctest: +SKIP
 
+
     References
     ----------
     * `Solar and Geomagnetic Indices Data Archive <http://legacy-www.swpc.noaa.gov/Data/index.html#indices>`_
@@ -164,26 +167,29 @@ class NOAAPredictIndicesLightCurve(LightCurve):
 
     """
 
-    def peek(self, **plot_args):
-        """Plots predicted NOAA Indices as a function of time. An example is shown below.
+    default_url_noaa_predict_indices = "http://services.swpc.noaa.gov/text/predicted-sunspot-radio-flux.txt"
 
-        .. plot::
+    def peek(self, **plot_args):
+        """
+        Plots predicted NOAA Indices as a function of time. An example is shown below.
+
+        ..plot::
 
             from sunpy import lightcurve as lc
-            from sunpy.data.sample import NOAAPREDICT_LIGHTCURVE
-            noaa = lc.NOAAPredictIndicesLightCurve.create(NOAAPREDICT_LIGHTCURVE)
+            from sunpy.data.sample import NOAAPREDICT_TIMESERIES
+            noaa = lc.NOAAPredictIndicesLightCurve.create(NOAAPREDICT_TIMESERIES)
             noaa.peek()
 
         Parameters
         ----------
         **plot_args : dict
-            Any additional plot arguments that should be used
-            when plotting.
+            Any additional plot arguments that should be used when plotting.
 
         Returns
         -------
         fig : `~matplotlib.Figure`
             A plot figure.
+
         """
 
         figure = plt.figure()
@@ -207,13 +213,13 @@ class NOAAPredictIndicesLightCurve(LightCurve):
 
     @classmethod
     def _get_default_uri(cls):
-        """Return the url to download indices."""
-        return "http://services.swpc.noaa.gov/text/predicted-sunspot-radio-flux.txt"
+        """Return the url to download indices"""
+        return NOAAPredictIndicesLightCurve.default_url_noaa_predict_indices
 
     @staticmethod
     def _get_url_for_date_range(*args, **kwargs):
         """Returns a URL for the specified date."""
-        return NOAAPredictIndicesLightCurve._get_default_uri()
+        return NOAAPredictIndicesLightCurve.default_url_noaa_predict_indices
 
     @staticmethod
     def _parse_csv(filepath):
