@@ -11,24 +11,24 @@ timerange_a = TimeRange('2004/01/01', '2007/01/01')
 
 class TestNOAAIndicesLightCurve(object):
 
-    @pytest.mark.online
+    @pytest.mark.remote_data
     def test_create(self):
         lc = sunpy.lightcurve.NOAAIndicesLightCurve.create()
         assert isinstance(lc, sunpy.lightcurve.NOAAIndicesLightCurve)
 
-    @pytest.mark.online
+    @pytest.mark.remote_data
     def test_isempty(self):
         lc = sunpy.lightcurve.NOAAIndicesLightCurve.create()
         assert lc.data.empty == False
 
-    @pytest.mark.online
+    @pytest.mark.remote_data
     def test_url(self):
         """Test creation with url"""
         url = 'ftp://ftp.swpc.noaa.gov/pub/weekly/RecentIndices.txt'
         lc1 = sunpy.lightcurve.NOAAIndicesLightCurve.create(url)
         assert isinstance(lc1, sunpy.lightcurve.NOAAIndicesLightCurve)
 
-    @pytest.mark.online
+    @pytest.mark.remote_data
     def test_goes_timerange(self):
         """Test creation with a TimeRange"""
         lc1 = sunpy.lightcurve.NOAAIndicesLightCurve.create(timerange_a)
@@ -39,7 +39,7 @@ class TestNOAAIndicesLightCurve(object):
         g = sunpy.lightcurve.NOAAIndicesLightCurve
         assert g._get_url_for_date_range(timerange_a) == 'ftp://ftp.swpc.noaa.gov/pub/weekly/RecentIndices.txt'
 
-    @pytest.mark.online
+    @pytest.mark.remote_data
     def test_header(self):
         """Test presence of GOES satellite number in header"""
         lc1 = sunpy.lightcurve.NOAAIndicesLightCurve.create()
@@ -48,25 +48,25 @@ class TestNOAAIndicesLightCurve(object):
 
 class TestNOAAPredictIndicesLightCurve(object):
 
-    @pytest.mark.online
+    @pytest.mark.remote_data
     def test_create(self):
         """Test creation with no input"""
         lc = sunpy.lightcurve.NOAAPredictIndicesLightCurve.create()
         assert isinstance(lc, sunpy.lightcurve.NOAAPredictIndicesLightCurve)
 
-    @pytest.mark.online
+    @pytest.mark.remote_data
     def test_isempty(self):
         """Test presence of data"""
         lc = sunpy.lightcurve.NOAAPredictIndicesLightCurve.create()
         assert lc.data.empty == False
 
-    @pytest.mark.online
+    @pytest.mark.remote_data
     def test_goes_timerange(self):
         """Test creation with a TimeRange"""
         lc1 = sunpy.lightcurve.NOAAPredictIndicesLightCurve.create(timerange_a)
         assert isinstance(lc1, sunpy.lightcurve.NOAAPredictIndicesLightCurve)
 
-    @pytest.mark.online
+    @pytest.mark.remote_data
     def test_url(self):
         """Test creation with url"""
         url = 'http://services.swpc.noaa.gov/text/predicted-sunspot-radio-flux.txt'
@@ -78,7 +78,7 @@ class TestNOAAPredictIndicesLightCurve(object):
         g = sunpy.lightcurve.NOAAPredictIndicesLightCurve
         assert g._get_url_for_date_range(timerange_a) == 'http://services.swpc.noaa.gov/text/predicted-sunspot-radio-flux.txt'
 
-    @pytest.mark.online
+    @pytest.mark.remote_data
     def test_header(self):
         """Test presence of GOES satellite number in header"""
         lc1 = sunpy.lightcurve.NOAAPredictIndicesLightCurve.create()
