@@ -13,6 +13,7 @@ import astropy.units as u
 from sunpy.map import GenericMap
 from sunpy.visualization.mapcubeanimator import MapCubeAnimator
 from sunpy.visualization import wcsaxes_compat
+from sunpy.visualization import axis_labels_from_ctype
 from sunpy.util import expand_list
 from sunpy.extern.six.moves import range
 
@@ -91,7 +92,7 @@ class MapCube(object):
     # Sorting methods
     @classmethod
     def _sort_by_date(cls):
-        return lambda m: m.date # maps.sort(key=attrgetter('date'))
+        return lambda m: m.date  # maps.sort(key=attrgetter('date'))
 
     def _derotate(self):
         """Derotates the layers in the MapCube"""
@@ -176,21 +177,10 @@ class MapCube(object):
         # Normal plot
         def annotate_frame(i):
             axes.set_title("{s.name}".format(s=self[i]))
-
-            # x-axis label
-            if self[0].coordinate_system.x == 'HG':
-                xlabel = 'Longitude [{lon}'.format(lon=self[i].spatial_units.x)
-            else:
-                xlabel = 'X-position [{xpos}]'.format(xpos=self[i].spatial_units.x)
-
-            # y-axis label
-            if self[0].coordinate_system.y == 'HG':
-                ylabel = 'Latitude [{lat}]'.format(lat=self[i].spatial_units.y)
-            else:
-                ylabel = 'Y-position [{ypos}]'.format(ypos=self[i].spatial_units.y)
-
-            axes.set_xlabel(xlabel)
-            axes.set_ylabel(ylabel)
+            axes.set_xlabel(axis_labels_from_ctype(self[i].coordinate_system[0],
+                                                   self[i].spatial_units[0]))
+            axes.set_ylabel(axis_labels_from_ctype(self[i].coordinate_system[1],
+                                                   self[i].spatial_units[1]))
 
         if resample:
             if self.all_maps_same_shape():
