@@ -6,9 +6,6 @@ __author__ = ["Jack Ireland, Jose Ivan Campos-Rozo, David Perez-Suarez"]
 __email__ = "jack.ireland@nasa.gov"
 
 import numpy as np
-import numpy.ma as ma
-from matplotlib import colors
-
 from sunpy.map import GenericMap
 from sunpy.cm import cm
 
@@ -19,8 +16,10 @@ __all__ = ['XRTMap', 'SOTMap']
 # http://darts.jaxa.jp/pub/ssw/hinode/xrt/idl/util/xrt_prep.pro
 # SATURATION_LIMIT = 2500
 
-def _lower_list(L):
-    return [item.lower() for item in L]
+
+def _lower_list(l):
+    return [item.lower() for item in l]
+
 
 class XRTMap(GenericMap):
     """Hinode XRT map definition.
@@ -68,7 +67,6 @@ class XRTMap(GenericMap):
         self.meta['telescop'] = "Hinode"
         self.meta['wavelnth'] = np.nan
         self.meta['waveunit'] = 'keV'
-        self._nickname = "{0} {1}-{2}".format(self.detector, fw1, fw2)
         self.plot_settings['cmap'] = cm.get_cmap(name='hinodexrt')
 
     @property
@@ -82,6 +80,7 @@ class XRTMap(GenericMap):
         """Determines if header corresponds to an XRT image"""
         return header.get('instrume') == 'XRT'
 
+
 class SOTMap(GenericMap):
     """Hinode SOT Image Map definition.
 
@@ -100,7 +99,7 @@ class SOTMap(GenericMap):
     * `Hinode SOT Instrument Paper <http://arxiv.org/pdf/0711.1715.pdf>`_
     * `Data Analsis Guide <https://sot.lmsal.com/doc/rep/sot254/fid366/SOT00042_33_SOT_Analysis_Guide_SAG.pdf>`_
     """
-    #TODO: get a link for the SOT FITS headers
+    # TODO: get a link for the SOT FITS headers
     # Add in some information about the the possible instrument, observation
     # type, observable ion and wavelength
 
@@ -123,14 +122,15 @@ class SOTMap(GenericMap):
         self.meta['telescop'] = "Hinode"
         self._nickname = self.detector
 
-        #TODO (add other options, Now all threated as intensity. This follows Hinode SDC archive)
-        # StokesQUV -> grey, Velocity -> EIS, Width -> EIS, Mag Field Azi -> IDL 5 (STD gamma II)
+        # TODO (add other options, Now all threated as intensity. This follows
+        # Hinode SDC archive) StokesQUV -> grey, Velocity -> EIS, Width -> EIS,
+        # Mag Field Azi -> IDL 5 (STD gamma II)
         # 'WB' -> red
         # 'NB'(0 = red); (>0 = gray), # nb has 1 stokes I, the rest quv
         # 'SP' (<=1 = red); (>1 = gray) #sp has 2 stokes I, the rest quv
         color = {'SOT/WB': 'intensity',
-                 'SOT/NB': 'intensity', # For the 1st dimension
-                 'SOT/SP': 'intensity', # For the 1st 2 dimensions
+                 'SOT/NB': 'intensity',  # For the 1st dimension
+                 'SOT/SP': 'intensity',  # For the 1st 2 dimensions
                  }
 
         self.plot_settings['cmap'] = cm.get_cmap('hinodesot' + color[self.instrument])
