@@ -5,15 +5,16 @@ from __future__ import absolute_import, print_function, division
 __author__ = "Keith Hughitt"
 __email__ = "keith.hughitt@nasa.gov"
 
-import numpy as np
 from astropy.visualization.mpl_normalize import ImageNormalize
-from astropy import visualization
+from astropy.visualization import AsinhStretch
 
 from sunpy.map import GenericMap
 from sunpy.cm import cm
+from sunpy.map.sources.source_type import source_stretch
 
 __all__ = ['AIAMap', 'HMIMap']
 
+
 class AIAMap(GenericMap):
     """AIA Image Map.
 
@@ -45,7 +46,7 @@ class AIAMap(GenericMap):
         self.meta['detector'] = "AIA"
         self._nickname = self.detector
         self.plot_settings['cmap'] = cm.get_cmap(self._get_cmap_name())
-        self.plot_settings['norm'] = ImageNormalize(stretch=visualization.AsinhStretch(0.01))
+        self.plot_settings['norm'] = ImageNormalize(stretch=source_stretch(self.meta, AsinhStretch(0.01)))
 
     @property
     def observatory(self):
@@ -54,18 +55,12 @@ class AIAMap(GenericMap):
         """
         return self.meta['telescop'].split('/')[0]
 
-    @property
-    def processing_level(self):
-        """
-        Returns the FITS processing level.
-        """
-        return self.meta['lvl_num']
-
     @classmethod
     def is_datasource_for(cls, data, header, **kwargs):
         """Determines if header corresponds to an AIA image"""
         return header.get('instrume', '').startswith('AIA')
 
+
 class HMIMap(GenericMap):
     """HMI Image Map.
 
