@@ -5,5 +5,4 @@ from __future__ import absolute_import
 The following link is the link to the registry, should it be necessary, this
 link can easily be replaced or swapped.
 """
-LINK = 'http://registry.helio-vo.eu/helio_registry/viewResourceEntry_body.jsp?'\
-       'XML=true&IVORN=ivo://helio-vo.eu'
+LINK = 'http://helio.ukssdc.ac.uk/helio_registry/viewResourceEntry_body.jsp?XML=true&IVORN=ivo://helio-vo.eu'
