@@ -1,28 +1,11 @@
 from __future__ import absolute_import
 
-__all__ = ['Series', 'Protocol', 'Notify', 'Compression', 'Wavelength', 'Time',
-           'Segment', 'Sample']
-
-import astropy.units as u
-
-from sunpy.net.attr import Attr, AttrWalker, AttrAnd, AttrOr
+from sunpy.net.attr import AttrWalker, AttrAnd, AttrOr
 from sunpy.net.vso.attrs import _VSOSimpleAttr
-from sunpy.net.vso.attrs import Time as vTime, Sample as vSample
-
-###############################################################################
-# This is a horrific hack to make automodapi pick up these as jsoc attrs.
+from sunpy.net.vso.attrs import Time, Wavelength
 
 
-class Time(vTime):
-    __doc__ = vTime.__doc__
-    pass
-
-
-class Sample(vSample):
-    __doc__ = vSample.__doc__
-    pass
-
-###############################################################################
+__all__ = ['Series', 'Protocol', 'Notify', 'Compression', 'Segment']
 
 
 class Series(_VSOSimpleAttr):
@@ -56,6 +39,7 @@ class Notify(_VSOSimpleAttr):
     """
     An email address to get a notification to when JSOC has staged your request
     """
+
     def __init__(self, value):
         super(Notify, self).__init__(value)
         if value.find('@') == -1:
@@ -73,27 +57,6 @@ class Compression(_VSOSimpleAttr):
     pass
 
 
-class Wavelength(_VSOSimpleAttr):
-    """
-    Wavelength or list of wavelengths to download. Must be specified in correct
-    units for the series.
-    """
-    def __init__(self, value):
-        if not (isinstance(value, u.Quantity) or isinstance(value, list)):
-            raise TypeError("Wave inputs must be astropy Quantities")
-        Attr.__init__(self)
-
-        self.value = value
-
-    def __or__(self, other):
-        if self == other:
-            return self
-        if isinstance(other, self.__class__):
-            return self.__class__([self.value, other.value])
-        return AttrOr([self, other])
-    __ror__ = __or__
-
-
 walker = AttrWalker()
 
 
@@ -120,11 +83,19 @@ def _apply1(wlk, query, imap):
 
 @walker.add_applier(Time)
 def _apply2(wlk, query, imap):
-
     imap['start_time'] = query.start
     imap['end_time'] = query.end
 
 
+@walker.add_applier(Wavelength)
+def _apply_wave(wlk, query, imap):
+    if query.min != query.max:
+        raise ValueError(
+            "For JSOC queries Wavelength.min must equal Wavelength.max")
+
+    imap[query.__class__.__name__.lower()] = query.min
+
+
 @walker.add_creator(AttrOr)
 def _create1(wlk, query):
 
