@@ -233,6 +233,8 @@ class Provider(_VSOSimpleAttr):
     ----------
     value : string
 
+    Notes
+    -----
     More information about each source may be found within in the VSO Registry.
     For a list of sources see
     http://sdac.virtualsolar.org/cgi/show_details?keyword=PROVIDER.
@@ -248,6 +250,8 @@ class Source(_VSOSimpleAttr):
     ----------
     value : string
 
+    Notes
+    -----
     More information about each source may be found within in the VSO Registry.
     User Interface programmers should note that some names may be encoded as
     UTF-8. Please note that 'Source' is used internally by VSO to represent
@@ -267,7 +271,6 @@ class Instrument(_VSOSimpleAttr):
 
     Notes
     -----
-
     More information about each instrument supported by the VSO may be found
     within the VSO Registry. For a list of instruments see
     http://sdac.virtualsolar.org/cgi/show_details?keyword=INSTRUMENT.
@@ -287,10 +290,14 @@ class Detector(_VSOSimpleAttr):
     ----------
     value : string
 
+    Notes
+    -----
     For a list of values understood by the VSO see
     http://sdac.virtualsolar.org/cgi/show_details?keyword=SOURCE.
 
-    Reference: documentation in SSWIDL routine vso_search.pro.
+    References
+    ----------
+    Documentation in SSWIDL routine vso_search.pro.
     """
     pass
 
@@ -303,6 +310,8 @@ class Physobs(_VSOSimpleAttr):
     ----------
     value : string
 
+    Notes
+    -----
     More information about each instrument may be found within the VSO
     Registry.  For a list of physical observables see
     http://sdac.virtualsolar.org/cgi/show_details?keyword=PHYSOBS.
@@ -319,11 +328,12 @@ class Level(_VSOSimpleAttr):
     ----------
     value : float or string
 
-    The value can be entered in of three ways
-    (1) May be entered as a string or any numeric type for equality matching
-    (2) May be a string of the format '(min) - (max)' for range matching
-    (3) May be a string of the form '(operator) (number)' where operator is
-    one of: lt gt le ge < > <= >=
+        The value can be entered in of three ways:
+
+        #. May be entered as a string or any numeric type for equality matching
+        #. May be a string of the format '(min) - (max)' for range matching
+        #. May be a string of the form '(operator) (number)' where operator is\
+        one of: lt gt le ge < > <= >=
 
     """
     pass
@@ -335,7 +345,9 @@ class Pixels(_VSOSimpleAttr):
     for SDO data)  We hope to change this in the future to support TRACE,
     Hinode and other investigations where this changed between observations.
 
-    Reference: documentation in SSWIDL routine vso_search.pro.
+    References
+    ----------
+    Documentation in SSWIDL routine vso_search.pro.
     """
     pass
 
@@ -348,19 +360,22 @@ class Resolution(_VSOSimpleAttr):
     ----------
     value : float or string
 
-    The value can be entered in of three ways
-    (1) May be entered as a string or any numeric type for equality matching
-    (2) May be a string of the format '(min) - (max)' for range matching
-    (3) May be a string of the form '(operator) (number)' where operator is
-    one of: lt gt le ge < > <= >=
+        The value can be entered in of three ways:
 
-    This attribute is currently implemented for SDO/AIA and HMI only.
-    The "resolution" is a function of the highest level of data available.
-    If the CCD is 2048x2048, but is binned to 512x512 before downlink,
-    the 512x512 product is designated as '1'.  If a 2048x2048 and 512x512
-    product are both available, the 512x512 product is designated '0.25'.
+        #. May be entered as a string or any numeric type for equality matching
+        #. May be a string of the format '(min) - (max)' for range matching
+        #. May be a string of the form '(operator) (number)' where operator is\
+        one of: lt gt le ge < > <= >=
 
-    Reference: documentation in SSWIDL routine vso_search.pro.
+        This attribute is currently implemented for SDO/AIA and HMI only.
+        The "resolution" is a function of the highest level of data available.
+        If the CCD is 2048x2048, but is binned to 512x512 before downlink,
+        the 512x512 product is designated as '1'.  If a 2048x2048 and 512x512
+        product are both available, the 512x512 product is designated '0.25'.
+
+    References
+    ----------
+    Documentation in SSWIDL routine vso_search.pro.
     """
     pass
 
@@ -373,15 +388,19 @@ class PScale(_VSOSimpleAttr):
     ----------
     value : float or string
 
-    The value can be entered in of three ways
-    (1) May be entered as a string or any numeric type for equality matching
-    (2) May be a string of the format '(min) - (max)' for range matching
-    (3) May be a string of the form '(operator) (number)' where operator is
-    one of: lt gt le ge < > <= >=
+        The value can be entered in of three ways:
 
-    Currently only implemented for SDO, which is 0.6 arcsec per pixel at full
-    resolution for AIA.  Reference: documentation in SSWIDL routine
-    vso_search.pro.
+        #. May be entered as a string or any numeric type for equality matching
+        #. May be a string of the format '(min) - (max)' for range matching
+        #. May be a string of the form '(operator) (number)' where operator is\
+        one of: lt gt le ge < > <= >=
+
+        Currently only implemented for SDO, which is 0.6 arcsec per pixel at full
+        resolution for AIA.
+
+    References
+    ----------
+    Documentation in SSWIDL routine vso_search.pro.
     """
     pass
 
@@ -410,12 +429,15 @@ class Quicklook(_VSOSimpleAttr):
     value : boolean
         Set to True to retrieve quicklook data if available.
 
-    Quicklook items are assumed to be generated with a focus on speed rather
-    than scientific accuracy.  They are useful for instrument planning and
-    space weather but should not be used for science publication.
-    This concept is sometimes called 'browse' or 'near real time' (nrt)
-    Quicklook products are *not* searched by default.   Reference:
-    documentation in SSWIDL routine vso_search.pro.
+        Quicklook items are assumed to be generated with a focus on speed rather
+        than scientific accuracy.  They are useful for instrument planning and
+        space weather but should not be used for science publication.
+        This concept is sometimes called 'browse' or 'near real time' (nrt)
+        Quicklook products are *not* searched by default.
+
+    References
+    ----------
+    Documentation in SSWIDL routine vso_search.pro.
     """
     def __init__(self, value):
         super(Quicklook, self).__init__(value)
