@@ -1,5 +1,7 @@
 import warnings
-warnings.warn("""The module 'sunpy.physics.transforms.differential_rotation.py'
+warnings.warn(
+    """The module 'sunpy.physics.transforms.differential_rotation.py'
 is deprecated and will be removed in the future. Use 'sunpy.physics.differential_rotation.py' instead""",
-stacklevel=2)
+    stacklevel=2)
+
 from sunpy.physics.differential_rotation import *
