@@ -16,6 +16,7 @@ from astropy.coordinates import Angle, Longitude, Latitude
 from sunpy.time import parse_time, julian_day, julian_centuries
 from sunpy.sun import constants
 from sunpy.util.decorators import deprecated
+from sunpy.extern import six
 
 __all__ = [
     "print_params", "heliographic_solar_center", "solar_north", "apparent_declination",
@@ -47,14 +48,34 @@ Carrington Rotation Number = 1971.4091        check!
 __authors__ = ["Steven Christe"]
 __email__ = "steven.d.christe@nasa.gov"
 
+PARAMETER_DOCS = """
+    Parameters
+    ----------
+    t :  [ int, float, time_string, datetime ], optional
+        Time, which can be either time_string, int, or datetime object. Parsed
+        using `~sunpy.time.parse_time`. Defaults to the current time.
 
+"""
+
+
+def add_parameter_docs(f):
+    if isinstance(f.__doc__, six.string_types):
+        f.__doc__ += PARAMETER_DOCS
+    return f
+
+
+@add_parameter_docs
 def solar_cycle_number(t='now'):
-    """Return the solar cycle number."""
+    """
+    Return the solar cycle number.
+
+    """
     time = parse_time(t)
     result = (time.year + 8) % 28 + 1
     return result
 
 
+@add_parameter_docs
 def solar_semidiameter_angular_size(t='now'):
     r"""
     Return the angular size of the semi-diameter of the Sun as
@@ -77,61 +98,89 @@ def solar_semidiameter_angular_size(t='now'):
     return Angle(solar_semidiameter_rad.to(u.arcsec, equivalencies=u.dimensionless_angles()))
 
 
+@add_parameter_docs
 def position(t='now'):
-    """Returns the position of the Sun (right ascension and declination)
+    """
+    Returns the position of the Sun (right ascension and declination)
     on the celestial sphere using the equatorial coordinate system in arcsec.
+
     """
     ra = true_rightascension(t)
     dec = true_declination(t)
     return ra, dec
 
 
+@add_parameter_docs
 def eccentricity_SunEarth_orbit(t='now'):
-    """Returns the eccentricity of the Sun Earth Orbit."""
+    """
+    Returns the eccentricity of the Sun Earth Orbit.
+
+    """
     T = julian_centuries(t)
     result = 0.016751040 - 0.00004180 * T - 0.0000001260 * T**2
     return result
 
 
+@add_parameter_docs
 def mean_ecliptic_longitude(t='now'):
-    """Returns the mean ecliptic longitude."""
+    """
+    Returns the mean ecliptic longitude.
+
+    """
     T = julian_centuries(t)
     result = 279.696680 + 36000.76892 * T + 0.0003025 * T**2
     result = result * u.deg
     return Longitude(result)
 
 
+@add_parameter_docs
 def longitude_Sun_perigee(t='now'):  # pylint: disable=W0613
     # T = julian_centuries(t)
     return 1
 
 
+@add_parameter_docs
 def mean_anomaly(t='now'):
-    """Returns the mean anomaly (the angle through which the Sun has moved
-    assuming a circular orbit) as a function of time."""
+    """
+    Returns the mean anomaly (the angle through which the Sun has moved
+    assuming a circular orbit) as a function of time.
+
+    """
     T = julian_centuries(t)
     result = 358.475830 + 35999.049750 * T - 0.0001500 * T**2 - 0.00000330 * T**3
     result = result * u.deg
     return Longitude(result)
 
 
+@add_parameter_docs
 def carrington_rotation_number(t='now'):
-    """Return the Carrington Rotation number"""
+    """
+    Return the Carrington Rotation number
+
+    """
     jd = julian_day(t)
     result = (1. / 27.2753) * (jd - 2398167.0) + 1.0
     return result
 
 
+@add_parameter_docs
 def geometric_mean_longitude(t='now'):
-    """Returns the geometric mean longitude (in degrees)"""
+    """
+    Returns the geometric mean longitude (in degrees).
+
+    """
     T = julian_centuries(t)
     result = 279.696680 + 36000.76892 * T + 0.0003025 * T**2
     result = result * u.deg
     return Longitude(result)
 
 
+@add_parameter_docs
 def equation_of_center(t='now'):
-    """Returns the Sun's equation of center (in degrees)"""
+    """
+    Returns the Sun's equation of center (in degrees).
+
+    """
     T = julian_centuries(t)
     mna = mean_anomaly(t)
     result = ((1.9194600 - 0.0047890 * T - 0.0000140 * T**2) * np.sin(mna) +
@@ -140,32 +189,48 @@ def equation_of_center(t='now'):
     return Angle(result)
 
 
+@add_parameter_docs
 def true_longitude(t='now'):
-    """Returns the Sun's true geometric longitude (in degrees)
+    """
+    Returns the Sun's true geometric longitude (in degrees).
     (Referred to the mean equinox of date.  Question: Should the higher
-    accuracy terms from which app_long is derived be added to true_long?)"""
+    accuracy terms from which app_long is derived be added to true_long?)
+
+    """
     result = equation_of_center(t) + geometric_mean_longitude(t)
     return Longitude(result)
 
 
+@add_parameter_docs
 def true_anomaly(t='now'):
-    """Returns the Sun's true anomaly (in degrees)."""
+    """
+    Returns the Sun's true anomaly (in degrees).
+
+    """
     result = mean_anomaly(t) + equation_of_center(t)
     return Longitude(result)
 
 
 @deprecated('0.8', 'Use sunpy.coordinates.get_sunearth_distance() for higher accuracy')
+@add_parameter_docs
 def sunearth_distance(t='now'):
-    """Returns the Sun Earth distance (AU). There are a set of higher
-    accuracy terms not included here."""
+    """
+    Returns the Sun Earth distance (AU). There are a set of higher
+    accuracy terms not included here.
+
+    """
     ta = true_anomaly(t)
     e = eccentricity_SunEarth_orbit(t)
     result = 1.00000020 * (1.0 - e**2) / (1.0 + e * np.cos(ta))
     return result * u.AU
 
 
+@add_parameter_docs
 def apparent_longitude(t='now'):
-    """Returns the apparent longitude of the Sun."""
+    """
+    Returns the apparent longitude of the Sun.
+
+    """
     T = julian_centuries(t)
     omega = (259.18 - 1934.142 * T) * u.deg
     true_long = true_longitude(t)
@@ -173,55 +238,87 @@ def apparent_longitude(t='now'):
     return Longitude(result)
 
 
+@add_parameter_docs
 def true_latitude(t='now'):  # pylint: disable=W0613
-    """Returns the true latitude. Never more than 1.2 arcsec from 0,
-    set to 0 here."""
+    """
+    Returns the true latitude. Never more than 1.2 arcsec from 0,
+    set to 0 here.
+
+    """
     return Latitude(0.0 * u.deg)
 
 
+@add_parameter_docs
 def apparent_latitude(t='now'):  # pylint: disable=W0613
-    """Returns the true latitude. Set to 0 here."""
+    """
+    Returns the true latitude. Set to 0 here.
+
+    """
     return Latitude(0.0 * u.deg)
 
 
+@add_parameter_docs
 def true_obliquity_of_ecliptic(t='now'):
-    """Returns the true obliquity of the ecliptic."""
+    """
+    Returns the true obliquity of the ecliptic.
+
+    """
     T = julian_centuries(t)
     result = 23.452294 - 0.0130125 * T - 0.00000164 * T**2 + 0.000000503 * T**3
     return Angle(result, u.deg)
 
 
+@add_parameter_docs
 def true_rightascension(t='now'):
-    """Return the true right ascension."""
+    """
+    Return the true right ascension.
+
+    """
     y = np.cos(true_obliquity_of_ecliptic(t)) * np.sin(true_longitude(t))
     x = np.cos(true_longitude(t))
     true_ra = np.arctan2(y, x)
     return Longitude(true_ra.to(u.hourangle))
 
 
+@add_parameter_docs
 def true_declination(t='now'):
-    """Return the true declination."""
+    """
+    Return the true declination.
+
+    """
     result = np.arcsin(np.sin(true_obliquity_of_ecliptic(t)) * np.sin(apparent_longitude(t)))
     return Latitude(result.to(u.deg))
 
 
+@add_parameter_docs
 def apparent_obliquity_of_ecliptic(t='now'):
-    """Return the apparent obliquity of the ecliptic."""
+    """
+    Return the apparent obliquity of the ecliptic.
+
+    """
     omega = apparent_longitude(t)
     result = true_obliquity_of_ecliptic(t) + (0.00256 * np.cos(omega)) * u.deg
     return result
 
 
+@add_parameter_docs
 def apparent_rightascension(t='now'):
-    """Returns the apparent right ascension of the Sun."""
+    """
+    Returns the apparent right ascension of the Sun.
+
+    """
     y = np.cos(apparent_obliquity_of_ecliptic(t)) * np.sin(apparent_longitude(t))
     x = np.cos(apparent_longitude(t))
     app_ra = np.arctan2(y, x)
     return Longitude(app_ra.to(u.hourangle))
 
 
+@add_parameter_docs
 def apparent_declination(t='now'):
-    """Returns the apparent declination of the Sun."""
+    """
+    Returns the apparent declination of the Sun.
+
+    """
     ob = apparent_obliquity_of_ecliptic(t)
     app_long = apparent_longitude(t)
     result = np.arcsin(np.sin(ob)) * np.sin(app_long)
@@ -229,8 +326,12 @@ def apparent_declination(t='now'):
 
 
 @deprecated('0.8', 'Use sunpy.coordinates.get_sun_P() for higher accuracy')
+@add_parameter_docs
 def solar_north(t='now'):
-    """Returns the position of the Solar north pole in degrees."""
+    """
+    Returns the position of the Solar north pole in degrees.
+
+    """
     T = julian_centuries(t)
     ob1 = true_obliquity_of_ecliptic(t)
     # in degrees
@@ -247,8 +348,12 @@ def solar_north(t='now'):
 
 
 @deprecated('0.8', 'Use sunpy.coordinates.get_sun_L0() and .get_sun_B0() for higher accuracy')
+@add_parameter_docs
 def heliographic_solar_center(t='now'):
-    """Returns the position of the solar center in heliographic coordinates."""
+    """
+    Returns the position of the solar center in heliographic coordinates.
+
+    """
     jd = julian_day(t)
     T = julian_centuries(t)
     # Heliographic coordinates in degrees
@@ -267,8 +372,12 @@ def heliographic_solar_center(t='now'):
     return Longitude(he_lon.to(u.deg)), Latitude(he_lat.to(u.deg))
 
 
+@add_parameter_docs
 def print_params(t='now'):
-    """Print out a summary of Solar ephemeris"""
+    """
+    Print out a summary of Solar ephemeris.
+
+    """
 
     # import here to avoid circular import
     from sunpy.coordinates.ephemeris import (get_sun_L0, get_sun_B0,
