@@ -48,6 +48,17 @@ def test_parse_time_pandas_timestamp():
     assert dt == LANDING
 
 
+def test_parse_time_pandas_series():
+    inputs = [datetime(2012, 1, i) for i in range(1, 13)]
+    ind = pandas.Series(inputs)
+
+    dts = parse_time(ind)
+
+    assert isinstance(dts, np.ndarray)
+    assert all([isinstance(dt, datetime) for dt in dts])
+    assert list(dts) == inputs
+
+
 def test_parse_time_pandas_index():
     inputs = [datetime(2012, 1, i) for i in range(1, 13)]
     ind = pandas.DatetimeIndex(inputs)
@@ -77,6 +88,13 @@ def test_parse_time_numpy_datetime():
     assert all([isinstance(dt, datetime) for dt in dts])
 
 
+def test_parse_time_individual_numpy_datetime():
+    dt64 = np.datetime64('2005-02-01T00')
+    dt = parse_time(dt64)
+
+    assert isinstance(dt, datetime)
+
+
 def test_parse_time_astropy():
     astropy_time = parse_time(astropy.time.Time(['2016-01-02T23:00:01']))
 
