@@ -1,7 +1,6 @@
 from __future__ import absolute_import, division, print_function
 import re
-from datetime import datetime
-from datetime import timedelta
+from datetime import datetime, date, time, timedelta
 
 import numpy as np
 import pandas
@@ -126,6 +125,14 @@ def _astropy_time(time):
     return time if isinstance(time, astropy.time.Time) else astropy.time.Time(parse_time(time))
 
 
+def _parse_dt64(dt):
+    """
+    Parse a single numpy datetime64 object
+    """
+    # Validate (in an agnostic way) that we are getting a datetime rather than a date
+    return datetime(*(dt.astype(datetime).timetuple()[:6]))
+
+
 def parse_time(time_string, time_format='', **kwargs):
     """Given a time string will parse and return a datetime object.
     Similar to the anytim function in IDL.
@@ -156,18 +163,22 @@ def parse_time(time_string, time_format='', **kwargs):
     """
     if isinstance(time_string, pandas.Timestamp):
         return time_string.to_pydatetime()
+    elif isinstance(time_string, pandas.Series) and 'datetime64' in str(time_string.dtype):
+        return np.array([dt.to_pydatetime() for dt in time_string])
+    elif isinstance(time_string, pandas.DatetimeIndex):
+        return time_string._mpl_repr()
     elif isinstance(time_string, datetime) or time_format == 'datetime':
         return time_string
+    elif isinstance(time_string, date):
+        return datetime.combine(time_string, time())
     elif isinstance(time_string, tuple):
         return datetime(*time_string)
     elif time_format == 'utime' or isinstance(time_string, (int, float)):
         return datetime(1979, 1, 1) + timedelta(0, time_string)
-    elif isinstance(time_string, pandas.DatetimeIndex):
-        return time_string._mpl_repr()
+    elif isinstance(time_string, np.datetime64):
+        return _parse_dt64(time_string)
     elif isinstance(time_string, np.ndarray) and 'datetime64' in str(time_string.dtype):
-        ii = [ss.astype(datetime) for ss in time_string]
-        # Validate (in an agnostic way) that we are getting a datetime rather than a date
-        return np.array([datetime(*(dt.timetuple()[:6])) for dt in ii])
+        return np.array([_parse_dt64(dt) for dt in time_string])
     elif time_string is 'now':
         return datetime.utcnow()
     elif isinstance(time_string, astropy.time.Time):
@@ -192,18 +203,12 @@ def parse_time(time_string, time_format='', **kwargs):
 
         time_string_parse_format = kwargs.pop('_time_string_parse_format', None)
         if time_string_parse_format is not None:
-            # Following a comment by the Lead Developer, the Try / except clause
-            # is replaced.  The Lead Developer thinks that this the try/except
-            # clause is related to SunPy's database module.
-            try:
-                ts, time_delta = _regex_parse_time(time_string,
-                                                       time_string_parse_format)
-                if ts and time_delta:
-                    return datetime.strptime(ts, time_string_parse_format) + time_delta
-                else:
-                    return datetime.strptime(time_string, time_string_parse_format)
-            except Exception:
-                pass
+            ts, time_delta = _regex_parse_time(time_string,
+                                               time_string_parse_format)
+            if ts and time_delta:
+                return datetime.strptime(ts, time_string_parse_format) + time_delta
+            else:
+                return datetime.strptime(time_string, time_string_parse_format)
         raise ValueError("'{tstr!s}' is not a valid time string!".format(tstr=time_string))
 
 
