@@ -1,17 +1,28 @@
-"""This module tests the functions implemented in sunpy.util.util."""
+"""
+This module tests the functions implemented in sunpy.util.util.
+"""
+
 from __future__ import absolute_import, division, print_function
-
-import warnings
-
 import numpy as np
 
+import pytest
+from pytest_mock import mocker
+
 from sunpy.util import util
+
+
 def test_to_signed():
     """
-    This should return a signed type that can hold uint32.
+    This should return a signed type that can hold uint32 and ensure that
+    an exception is raised when attempting to convert an unsigned 64 bit integer
+    to an integer
     """
     assert util.to_signed(np.dtype('uint32')) == np.dtype('int64')
 
+    with pytest.raises(ValueError):
+        util.to_signed(np.dtype('uint64')) == np.dtype('int64')
+
+
 def test_unique():
     """
     This should add the unique values of itr to unique_list.
@@ -22,6 +33,7 @@ def test_unique():
         unique_list.append(elem)
     assert unique_list == [6, 1, 2, 7, 41.2, '41.2']
 
+
 def test_unique_key():
     """
     This should add each element of itr to unique_list if no preceding
@@ -33,27 +45,22 @@ def test_unique_key():
         unique_list.append(elem)
     assert unique_list == [7, 3, 104, 6, 10]
 
+
 def test_print_table():
     """
     This should return a string representation of lst with table elements
     left-justified and with columns separated by dashes.
     """
-    lst = [['n', 'sqrt(n)', 'n^2'], \
-           ['1', '1', '1'], \
-           ['4', '2', '16'], \
+    lst = [['n', 'sqrt(n)', 'n^2'],
+           ['1', '1', '1'],
+           ['4', '2', '16'],
            ['3', '1.732', '9']]
     expected = ('n|sqrt(n)|n^2\n'
-               '1|1      |1  \n'
-               '4|2      |16 \n'
-               '3|1.732  |9  ')
+                '1|1      |1  \n'
+                '4|2      |16 \n'
+                '3|1.732  |9  ')
     assert util.print_table(lst, colsep='|') == expected
 
-def test_polyfun_at():
-    """
-    This should evaluate the polynomial x^3 + 5x^2 - 6x + 3 at x = 5.
-    """
-    coeff = [1, 5, -6, 3]
-    assert util.polyfun_at(coeff, 5) == 223
 
 def test_minimal_pairs():
     """
@@ -65,6 +72,7 @@ def test_minimal_pairs():
     assert list(util.minimal_pairs(list1, list2)) == [(1, 0, 2), (2, 1, 2),
                                                       (4, 2, 1), (5, 4, 1)]
 
+
 def test_find_next():
     """
     This should return a generator yielding the nearest larger element in
@@ -73,8 +81,9 @@ def test_find_next():
     """
     list1 = [1, 2, 3, 4, 5, 6, 7, 8, 9]
     list2 = [0, 2, 3, 5, 0, 0, 5, 9, 10, 15]
-    assert list(util.find_next(list1, list2, None)) == [(1, 2), (2, 3), (3, 5),
-                        (4, 5), (5, 9), (6, 10), (7, 15), (8, None), (9, None)]
+    assert list(util.find_next(list1, list2, None)) == [(1, 2), (2, 3), (3, 5), (4, 5), (5, 9),
+                                                        (6, 10), (7, 15), (8, None), (9, None)]
+
 
 def test_common_base():
     """
@@ -83,9 +92,11 @@ def test_common_base():
     class TestA(object):
         """Base test class."""
         pass
+
     class TestB(TestA):
         """First inherited class."""
         pass
+
     class TestC(TestA):
         """Second inherited class."""
         pass
@@ -94,6 +105,7 @@ def test_common_base():
     objs = [inst_b, inst_c]
     assert util.common_base(objs) == TestA
 
+
 def test_merge():
     """
     This should return a sorted (from greatest to least) merged list
@@ -104,12 +116,26 @@ def test_merge():
     result = list(util.merge([list1, list2]))
     assert result[::-1] == sorted(result)
 
+    assert list(util.merge([[], [1], []])) == [1]
+
+
 def test_replacement_filename():
     """
     This should return a replacement path for the current file.
     """
     assert util.replacement_filename(__file__).endswith('test_util.0.py')
 
+
+def test_replacement_filename_path_not_exists(mocker):
+    """
+    If a candidate path does not exist, then just return it as it is OK to use
+    """
+    path_not_exists = '/tmp'
+    mocker.patch('os.path.exists', return_value=False)
+
+    assert util.replacement_filename(path_not_exists) == path_not_exists
+
+
 def test_expand_list():
     """
     This should return an expanded version of list lst.
@@ -117,12 +143,8 @@ def test_expand_list():
     lst = [1, 2, 3, [4, 5, 6], 7, (8, 9)]
     assert util.expand_list(lst) == [1, 2, 3, 4, 5, 6, 7, 8, 9]
 
-def test_deprecated():
-    """
-    This should trigger a deprecation warning.
-    """
-    depr = util.Deprecated()
-    with warnings.catch_warnings(record=True) as current_warnings:
-        depr_func = depr(lambda x: x)
-        depr_func(1)
-        assert len(current_warnings) == 1
+
+def test_expand_list_generator():
+
+    lst = ['a', 'b', [], (['c', 'd']), tuple(), ['e']]
+    assert list(util.expand_list_generator(lst)) == ['a', 'b', 'c', 'd', 'e']
