@@ -1,8 +1,10 @@
+"""
+General utility functions.
+"""
+
 from __future__ import absolute_import, division, print_function
 
 import os
-import types
-import warnings
 from itertools import count
 
 import numpy as np
@@ -10,13 +12,14 @@ import numpy as np
 from sunpy.extern import six
 from sunpy.extern.six.moves import map, zip
 
-__all__ = ['to_signed', 'unique', 'print_table',
-           'replacement_filename', 'merge', 'common_base',
-           'minimal_pairs', 'polyfun_at',
-           'expand_list', 'expand_list_generator', 'Deprecated']
+__all__ = ['to_signed', 'unique', 'print_table', 'replacement_filename',
+           'merge', 'common_base', 'minimal_pairs', 'expand_list',
+           'expand_list_generator']
+
 
 def to_signed(dtype):
-    """ Return dtype that can hold data of passed dtype but is signed.
+    """
+    Return dtype that can hold data of passed dtype but is signed.
     Raise ValueError if no such dtype exists.
 
     Parameters
@@ -27,6 +30,7 @@ def to_signed(dtype):
     Returns
     -------
     `numpy.dtype`
+
     """
     if dtype.kind == "u":
         if dtype.itemsize == 8:
@@ -34,6 +38,7 @@ def to_signed(dtype):
         dtype = "int{0:d}".format(min(dtype.itemsize * 2 * 8, 64))
     return np.dtype(dtype)
 
+
 def unique(itr, key=None):
     """
     not documented yet
@@ -45,11 +50,6 @@ def unique(itr, key=None):
 
     key : object
         not documented yet
-
-    Returns
-    -------
-    not documented yet
-
     """
     items = set()
     if key is None:
@@ -64,52 +64,11 @@ def unique(itr, key=None):
                 yield elem
                 items.add(x)
 
+
 def print_table(lst, colsep=' ', linesep='\n'):
-    """
-    ?
-
-    Parameters
-    ----------
-    lst : ?
-        ?
-    colsep : ?
-        ?
-    linesep : ?
-        ?
-
-    Returns
-    -------
-    ?
-
-    """
     width = [max(map(len, col)) for col in zip(*lst)]
     return linesep.join(
-        colsep.join(
-            col.ljust(n) for n, col in zip(width, row)
-        ) for row in lst
-    )
-
-
-def polyfun_at(coeff, p):
-    """ Return value of polynomial with coefficients (highest first) at
-    point (can also be an np.ndarray for more than one point) p.
-
-    Parameters
-    ----------
-    coeff : not documented yet
-        not documented yet
-    p : not documented yet
-        not documented yet
-
-    Returns
-    -------
-    not documented yet
-
-    .. todo::
-        improve documentation. what does this do?  Does numpy have this functionality?
-
-    """
-    return np.sum(k * p ** n for n, k in enumerate(reversed(coeff)))
+        colsep.join(col.ljust(n) for n, col in zip(width, row)) for row in lst)
 
 
 def minimal_pairs(one, other):
@@ -125,7 +84,6 @@ def minimal_pairs(one, other):
     -------
     `tuple`
          Pairs of values in `one` and `other` with minimal distance
-
     """
     lbestdiff = bestdiff = bestj = besti = None
     for i, freq in enumerate(one):
@@ -154,11 +112,13 @@ def minimal_pairs(one, other):
 
 
 DONT = object()
+
+
 def find_next(one, other, pad=DONT):
-    """ Given two sorted sequences one and other, for every element
+    """
+    Given two sorted sequences one and other, for every element
     in one, return the one larger than it but nearest to it in other.
     If no such exists and pad is not DONT, return value of pad as "partner".
-
     """
     n = 0
     for elem1 in one:
@@ -173,7 +133,8 @@ def find_next(one, other, pad=DONT):
 
 
 def common_base(objs):
-    """ Find class that every item of objs is an instance of.
+    """
+    Find class that every item of objs is an instance of.
     """
     for cls in objs[0].__class__.__mro__:
         if all(isinstance(obj, cls) for obj in objs):
@@ -182,7 +143,8 @@ def common_base(objs):
 
 
 def merge(items, key=(lambda x: x)):
-    """ Given sorted lists of iterables, return new iterable that returns
+    """
+    Given sorted lists of iterables, return new iterable that returns
     elements of all iterables sorted with respect to key.
     """
     state = {}
@@ -197,8 +159,8 @@ def merge(items, key=(lambda x: x)):
     while state:
         for item, (value, tk) in six.iteritems(state):
             # Value is biggest.
-            if all(tk >= k for it, (v, k)
-                in six.iteritems(state) if it is not item):
+            if all(tk >= k for it, (v, k) in six.iteritems(state)
+                   if it is not item):
                 yield value
                 break
         try:
@@ -207,8 +169,10 @@ def merge(items, key=(lambda x: x)):
         except StopIteration:
             del state[item]
 
+
 def replacement_filename(path):
-    """ Return replacement path for already used path. Enumerates
+    """
+    Return replacement path for already used path. Enumerates
     until an unused filename is found. E.g., "/home/florian/foo.fits"
     becomes "/home/florian/foo.0.fits", if that is used
     "/home/florian/foo.1.fits", etc.
@@ -225,13 +189,13 @@ def replacement_filename(path):
                 return newpath
 
 
-def expand_list(input):
+def expand_list(inp):
     """
     Expand a list of lists.
 
     Parameters
     ----------
-    input : `list`
+    inp : `list`
 
     Returns
     -------
@@ -243,40 +207,13 @@ def expand_list(input):
     Taken from :http://stackoverflow.com/a/2185971/2486799
 
     """
-    return [item for item in expand_list_generator(input)]
+    return [item for item in expand_list_generator(inp)]
 
-def expand_list_generator(input):
-    """
-    """
-    for item in input:
+
+def expand_list_generator(inp):
+    for item in inp:
         if type(item) in [list, tuple]:
             for nested_item in expand_list_generator(item):
                 yield nested_item
         else:
             yield item
-
-#==============================================================================
-# Deprecation decorator: http://code.activestate.com/recipes/391367-deprecated/
-# and http://www.artima.com/weblogs/viewpost.jsp?thread=240845
-#==============================================================================
-class Deprecated(object):
-    """ Use this decorator to deprecate a function or method, you can pass an
-    additional message to the decorator:
-
-    @Deprecated("no more")
-    """
-    def __init__(self, message=""):
-        self.message = message
-
-    def __call__(self, func):
-        def newFunc(*args, **kwargs):
-            warnings.warn("Call to deprecated function {0}. \n {1}".format(
-                                                                func.__name__,
-                                                                self.message),
-                          category=Warning, stacklevel=2)
-            return func(*args, **kwargs)
-
-        newFunc.__name__ = func.__name__
-        newFunc.__doc__ = func.__doc__
-        newFunc.__dict__.update(func.__dict__)
-        return newFunc
