@@ -1,11 +1,12 @@
 # -*- coding: utf-8 -*-
 
-__all__ = ['MapCubeAnimator']
-
 from copy import deepcopy
 
-from sunpy.visualization import imageanimator, wcsaxes_compat
-from sunpy.visualization.wcsaxes_compat import HAVE_WCSAXES, FORCE_NO_WCSAXES
+from sunpy.visualization import imageanimator, wcsaxes_compat, axis_labels_from_ctype
+from sunpy.visualization.wcsaxes_compat import _FORCE_NO_WCSAXES
+
+__all__ = ['MapCubeAnimator']
+
 
 class MapCubeAnimator(imageanimator.BaseFuncAnimator):
     """
@@ -48,6 +49,7 @@ class MapCubeAnimator(imageanimator.BaseFuncAnimator):
     Extra keywords are passed to `mapcube[0].plot()` i.e. the `plot()` routine of
     the maps in the cube.
     """
+
     def __init__(self, mapcube, annotate=True, **kwargs):
 
         self.mapcube = mapcube
@@ -57,31 +59,15 @@ class MapCubeAnimator(imageanimator.BaseFuncAnimator):
         # List of object to remove at the start of each plot step
         self.remove_obj = []
         slider_functions = [self.updatefig]
-        slider_ranges = [[0,len(mapcube.maps)]]
+        slider_ranges = [[0, len(mapcube.maps)]]
 
-        imageanimator.BaseFuncAnimator.__init__(self, mapcube.maps, slider_functions,
-                                        slider_ranges, **kwargs)
+        imageanimator.BaseFuncAnimator.__init__(
+            self, mapcube.maps, slider_functions, slider_ranges, **kwargs)
 
         if annotate:
             self._annotate_plot(0)
 
     def updatefig(self, val, im, slider):
-        """
-        ?
-
-        Parameters
-        ----------
-            val : ?
-                ?
-
-            im : ?
-                ?
-
-        Returns
-        -------
-        .. todo::
-            improve documentation
-        """
         # Remove all the objects that need to be removed from the
         # plot
         while self.remove_obj:
@@ -98,7 +84,9 @@ class MapCubeAnimator(imageanimator.BaseFuncAnimator):
 
         if wcsaxes_compat.is_wcsaxes(im.axes):
             im.axes.reset_wcs(self.mapcube[i].wcs)
-            wcsaxes_compat.default_wcs_grid(im.axes)
+            wcsaxes_compat.default_wcs_ticks(im.axes,
+                                             self.mapcube[i].spatial_units,
+                                             self.mapcube[i].coordinate_system)
 
         # Having this line in means the plot will resize for non-homogenous
         # maps. However it also means that if you zoom in on the plot bad
@@ -107,7 +95,8 @@ class MapCubeAnimator(imageanimator.BaseFuncAnimator):
         if self.annotate:
             self._annotate_plot(i)
 
-        self.remove_obj += list(self.user_plot_function(self.fig, self.axes, self.mapcube[i]))
+        self.remove_obj += list(
+            self.user_plot_function(self.fig, self.axes, self.mapcube[i]))
 
     def _annotate_plot(self, ind):
         """
@@ -118,32 +107,23 @@ class MapCubeAnimator(imageanimator.BaseFuncAnimator):
         # Normal plot
         self.axes.set_title("{s.name}".format(s=self.data[ind]))
 
-        # x-axis label
-        if self.data[ind].coordinate_system.x == 'HG':
-            xlabel = 'Longitude [{lon}]'.format(lon=self.data[ind].spatial_units.x)
-        else:
-            xlabel = 'X-position [{xpos}]'.format(xpos=self.data[ind].spatial_units.x)
-
-        # y-axis label
-        if self.data[ind].coordinate_system.y == 'HG':
-            ylabel = 'Latitude [{lat}]'.format(lat=self.data[ind].spatial_units.y)
-        else:
-            ylabel = 'Y-position [{ypos}]'.format(ypos=self.data[ind].spatial_units.y)
-
-        self.axes.set_xlabel(xlabel)
-        self.axes.set_ylabel(ylabel)
+        self.axes.set_xlabel(axis_labels_from_ctype(self.data[ind].coordinate_system[0],
+                                                    self.data[ind].spatial_units[0]))
+        self.axes.set_ylabel(axis_labels_from_ctype(self.data[ind].coordinate_system[1],
+                                                    self.data[ind].spatial_units[1]))
 
     def _get_main_axes(self):
         """
         Create an axes which is wcsaxes if we have that...
         """
-        if HAVE_WCSAXES and not FORCE_NO_WCSAXES:
+        if not _FORCE_NO_WCSAXES:
             return self.fig.add_subplot(111, projection=self.mapcube[0].wcs)
         else:
             return self.fig.add_subplot(111)
 
     def plot_start_image(self, ax):
-        im = self.mapcube[0].plot(annotate=self.annotate, axes=ax,
-                                       **self.imshow_kwargs)
-        self.remove_obj += list(self.user_plot_function(self.fig, self.axes, self.mapcube[0]))
+        im = self.mapcube[0].plot(
+            annotate=self.annotate, axes=ax, **self.imshow_kwargs)
+        self.remove_obj += list(
+            self.user_plot_function(self.fig, self.axes, self.mapcube[0]))
         return im
